'use strict';

var React = require('react');
var classnames = require('classnames');
var useResizeObserver = require('./useResizeObserver-cjs.js');
var BannerIcon = require('./BannerIcon-cjs.js');
var Text = require('./Text-cjs.js');
var Button = require('./Button-cjs.js');
var ButtonDismiss = require('./ButtonDismiss-cjs.js');

function Banner({ children, type, primaryAction, dismissible = true, icon, onDismiss, controlledVisiblity, }) {
    const [showBanner, setShowBanner] = React.useState(true);
    const bannerIcon = icon || getBannerIcon(type);
    const controlledVisible = controlledVisiblity !== null && controlledVisiblity !== void 0 ? controlledVisiblity : true;
    const visible = controlledVisible && showBanner;
    const bannerWidths = {
        small: 320,
        medium: 480,
    };
    const [bannerRef, { width: bannerWidth = bannerWidths.small }] = useResizeObserver.useResizeObserver.useResizeObserver({
        widths: bannerWidths,
    });
    if (primaryAction != undefined) {
        primaryAction = Object.assign({
            size: "small",
            type: "primary",
            variation: "subtle",
        }, primaryAction);
    }
    const bannerClassNames = classnames(BannerIcon.styles.banner, [BannerIcon.styles[type]], {
        [BannerIcon.styles.medium]: bannerWidth >= bannerWidths.medium,
    });
    if (!visible)
        return null;
    return (React.createElement("div", { className: bannerClassNames, ref: bannerRef, role: type === "error" ? "alert" : "status" },
        React.createElement("div", { className: BannerIcon.styles.bannerContent },
            bannerIcon && React.createElement(BannerIcon.BannerIcon, { icon: bannerIcon, type: type }),
            React.createElement("div", { className: BannerIcon.styles.bannerChildren },
                React.createElement(BannerChildren, null, children)),
            primaryAction && (React.createElement("div", { className: BannerIcon.styles.bannerAction },
                React.createElement(Button.Button, Object.assign({}, primaryAction))))),
        dismissible && (React.createElement("div", { className: BannerIcon.styles.closeButton },
            React.createElement(ButtonDismiss.ButtonDismiss, { ariaLabel: "Dismiss notification", onClick: handleClose })))));
    function handleClose() {
        if (typeof controlledVisiblity === "undefined") {
            setShowBanner(!showBanner);
        }
        onDismiss === null || onDismiss === void 0 ? void 0 : onDismiss();
    }
}
function getBannerIcon(type) {
    switch (type) {
        case "notice":
            return "info";
        case "success":
            return "checkmark";
        case "warning":
            return "warning";
        case "error":
            return "alert";
    }
}
function BannerChildren({ children, }) {
    if (!children)
        return React.createElement(React.Fragment, null);
    if (children && typeof children === "string") {
        return React.createElement(Text.Text, null, children);
    }
    return React.createElement(React.Fragment, null, children);
}

exports.Banner = Banner;
