import React__default, { useState } from 'react';
import classnames from 'classnames';
import { u as useResizeObserver } from './useResizeObserver-es.js';
import { s as styles, B as BannerIcon } from './BannerIcon-es.js';
import { T as Text } from './Text-es.js';
import { B as Button } from './Button-es.js';
import { B as ButtonDismiss } from './ButtonDismiss-es.js';

function Banner({ children, type, primaryAction, dismissible = true, icon, onDismiss, controlledVisiblity, }) {
    const [showBanner, setShowBanner] = useState(true);
    const bannerIcon = icon || getBannerIcon(type);
    const controlledVisible = controlledVisiblity !== null && controlledVisiblity !== void 0 ? controlledVisiblity : true;
    const visible = controlledVisible && showBanner;
    const bannerWidths = {
        small: 320,
        medium: 480,
    };
    const [bannerRef, { width: bannerWidth = bannerWidths.small }] = useResizeObserver.useResizeObserver({
        widths: bannerWidths,
    });
    if (primaryAction != undefined) {
        primaryAction = Object.assign({
            size: "small",
            type: "primary",
            variation: "subtle",
        }, primaryAction);
    }
    const bannerClassNames = classnames(styles.banner, [styles[type]], {
        [styles.medium]: bannerWidth >= bannerWidths.medium,
    });
    if (!visible)
        return null;
    return (React__default.createElement("div", { className: bannerClassNames, ref: bannerRef, role: type === "error" ? "alert" : "status" },
        React__default.createElement("div", { className: styles.bannerContent },
            bannerIcon && React__default.createElement(BannerIcon, { icon: bannerIcon, type: type }),
            React__default.createElement("div", { className: styles.bannerChildren },
                React__default.createElement(BannerChildren, null, children)),
            primaryAction && (React__default.createElement("div", { className: styles.bannerAction },
                React__default.createElement(Button, Object.assign({}, primaryAction))))),
        dismissible && (React__default.createElement("div", { className: styles.closeButton },
            React__default.createElement(ButtonDismiss, { ariaLabel: "Dismiss notification", onClick: handleClose })))));
    function handleClose() {
        if (typeof controlledVisiblity === "undefined") {
            setShowBanner(!showBanner);
        }
        onDismiss === null || onDismiss === void 0 ? void 0 : onDismiss();
    }
}
function getBannerIcon(type) {
    switch (type) {
        case "notice":
            return "info";
        case "success":
            return "checkmark";
        case "warning":
            return "warning";
        case "error":
            return "alert";
    }
}
function BannerChildren({ children, }) {
    if (!children)
        return React__default.createElement(React__default.Fragment, null);
    if (children && typeof children === "string") {
        return React__default.createElement(Text, null, children);
    }
    return React__default.createElement(React__default.Fragment, null, children);
}

export { Banner as B };
