'use strict';

var React = require('react');
var classnames = require('classnames');
var floatingUi_react = require('./floating-ui.react-cjs.js');
var ReactDOM = require('react-dom');
var ComboboxContentSearch = require('./ComboboxContentSearch-cjs.js');
var ComboboxContentList = require('./ComboboxContentList-cjs.js');
var ComboboxContentHeader = require('./ComboboxContentHeader-cjs.js');
var ComboboxProvider = require('./ComboboxProvider-cjs.js');
var useRefocusOnActivator = require('./useRefocusOnActivator-cjs.js');
var useFocusTrap = require('./useFocusTrap-cjs.js');
var constants = require('./constants-cjs.js');

var styles = {"content":"QsRc49DHSgA-","hidden":"_7Fd5XGsPpUA-","actions":"yV8-0Hs43J0-","actionPadding":"g3Gdt8jXvFk-","spinning":"dJVYYOaf04E-"};

function useComboboxContent(open, selected) {
    const { shouldScroll } = React.useContext(ComboboxProvider.ComboboxContext);
    const optionsListRef = React.useRef(null);
    React.useEffect(() => {
        var _a;
        if (open && shouldScroll.current && optionsListRef.current) {
            const firstSelected = Array.from((_a = optionsListRef === null || optionsListRef === void 0 ? void 0 : optionsListRef.current) === null || _a === void 0 ? void 0 : _a.children).find(child => {
                if (child instanceof HTMLElement) {
                    return child.dataset.selected === "true";
                }
            });
            scrollToFirstSelected(firstSelected, shouldScroll);
        }
    }, [open, selected]);
    return {
        optionsListRef,
    };
}
function scrollToFirstSelected(firstSelected, shouldScroll) {
    if (firstSelected) {
        firstSelected.scrollIntoView({
            block: "nearest",
        });
        shouldScroll.current = false;
    }
}

const COMBOBOX_OFFSET = 8;
// eslint-disable-next-line max-statements
function useComboboxAccessibility(selectionCallback, filteredOptions, optionsListRef, open, wrapperRef) {
    const { handleClose } = React.useContext(ComboboxProvider.ComboboxContext);
    const hasOptionsVisible = open && filteredOptions.length > 0;
    const focusedIndex = React.useRef(null);
    const parentNodeId = floatingUi_react.useFloatingParentNodeId();
    const nodeId = floatingUi_react.useFloatingNodeId();
    useRefocusOnActivator.useRefocusOnActivator_2(open);
    const popperRef = useFocusTrap.useFocusTrap_2(open);
    const { floatingStyles, update, context } = floatingUi_react.useFloating({
        nodeId,
        elements: {
            reference: wrapperRef.current,
            floating: popperRef.current,
        },
        open,
        onOpenChange: openState => {
            if (!openState)
                handleClose();
        },
        middleware: [
            floatingUi_react.autoPlacement({ allowedPlacements: ["bottom-start", "top-start"] }),
            floatingUi_react.offset(COMBOBOX_OFFSET),
            floatingUi_react.shift({ padding: COMBOBOX_OFFSET }),
        ],
        placement: "bottom-start",
        whileElementsMounted: floatingUi_react.autoUpdate,
    });
    const dismiss = floatingUi_react.useDismiss(context);
    const { getFloatingProps } = floatingUi_react.useInteractions([dismiss]);
    React.useEffect(() => {
        focusedIndex.current = null;
        if (open) {
            update === null || update === void 0 ? void 0 : update();
        }
    }, [open, filteredOptions.length, update]);
    React.useEffect(() => {
        var _a;
        if (open) {
            (_a = popperRef.current) === null || _a === void 0 ? void 0 : _a.addEventListener("keydown", handleContentKeydown);
        }
        return () => {
            var _a;
            (_a = popperRef.current) === null || _a === void 0 ? void 0 : _a.removeEventListener("keydown", handleContentKeydown);
        };
    }, [open, optionsListRef, filteredOptions]);
    function handleContentKeydown(event) {
        var _a;
        if (!hasOptionsVisible)
            return;
        if (event.key === "Enter" || event.key === " ") {
            const activeElementInList = (_a = optionsListRef.current) === null || _a === void 0 ? void 0 : _a.contains(document.activeElement);
            if (!activeElementInList)
                return;
            handleKeyboardSelection(event);
        }
        if (event.key === "ArrowDown") {
            handleKeyboardNavigation(event, 1);
        }
        if (event.key === "ArrowUp") {
            handleKeyboardNavigation(event, -1);
        }
    }
    function handleKeyboardNavigation(event, indexChange) {
        var _a;
        const newIndex = focusedIndex.current === null ? 0 : focusedIndex.current + indexChange;
        if (newIndex < 0 || newIndex >= filteredOptions.length)
            return;
        const optionElement = (_a = optionsListRef.current) === null || _a === void 0 ? void 0 : _a.children[newIndex];
        optionElement === null || optionElement === void 0 ? void 0 : optionElement.focus();
        focusedIndex.current = newIndex;
        event.preventDefault();
        event.stopPropagation();
    }
    function handleKeyboardSelection(event) {
        event.preventDefault();
        event.stopPropagation();
        if (focusedIndex.current !== null) {
            selectionCallback(filteredOptions[focusedIndex.current]);
        }
    }
    return {
        popperRef,
        popperStyles: floatingStyles,
        floatingProps: getFloatingProps(),
        nodeId,
        parentNodeId,
    };
}

function ComboboxContent(props) {
    const optionsExist = props.options.length > 0;
    const { optionsListRef } = useComboboxContent(props.open, props.selected);
    const { popperRef, popperStyles, floatingProps, nodeId, parentNodeId } = useComboboxAccessibility(props.handleSelection, props.options, optionsListRef, props.open, props.wrapperRef);
    const content = (React.createElement("div", Object.assign({ ref: popperRef, id: constants.COMBOBOX_MENU_ID, "data-testid": constants.COMBOBOX_MENU_ID, "data-elevation": "elevated", tabIndex: 0, className: classnames(styles.content, {
            [styles.hidden]: !props.open,
        }), style: popperStyles }, floatingProps),
        React.createElement(ComboboxContentSearch.ComboboxContentSearch, { open: props.open, placeholder: props.subjectNoun, searchValue: props.searchValue, setSearchValue: props.setSearchValue, handleSearchChange: props.handleSearchChange }),
        props.multiselect && (optionsExist || props.selected.length > 0) && (React.createElement(ComboboxContentHeader.ComboboxContentHeader, { hasOptionsVisible: optionsExist, subjectNoun: props.subjectNoun, selectedCount: props.selected.length, onClearAll: () => {
                props.selectedStateSetter([]);
            }, onSelectAll: () => {
                props.selectedStateSetter(props.options);
            } })),
        React.createElement(ComboboxContentList.ComboboxContentList, { multiselect: props.multiselect, options: props.options, selected: props.selected, optionsListRef: optionsListRef, searchValue: props.searchValue, subjectNoun: props.subjectNoun, loading: props.loading, onLoadMore: props.onLoadMore }),
        props.actionElements && (React.createElement("div", { className: styles.actions, role: "group" }, props.actionElements.map((child, index, childrenArray) => (React.createElement("div", { key: index, className: classnames({
                [styles.actionPadding]: index === childrenArray.length - 1,
            }) }, child)))))));
    if (parentNodeId) {
        return (React.createElement(floatingUi_react.FloatingTree, null,
            React.createElement(floatingUi_react.FloatingNode, { id: nodeId },
                React.createElement(floatingUi_react.FloatingPortal, null, content))));
    }
    return (globalThis === null || globalThis === void 0 ? void 0 : globalThis.document)
        ? ReactDOM.createPortal(content, document.body)
        : content;
}

exports.ComboboxContent = ComboboxContent;
