import React__default, { useContext, useRef, useEffect } from 'react';
import classnames from 'classnames';
import { u as useFloatingParentNodeId, a as useFloatingNodeId, b as useFloating, c as autoPlacement, o as offset, s as shift, d as autoUpdate, e as useDismiss, f as useInteractions, F as FloatingTree, g as FloatingNode, h as FloatingPortal } from './floating-ui.react-es.js';
import ReactDOM__default from 'react-dom';
import { C as ComboboxContentSearch } from './ComboboxContentSearch-es.js';
import { C as ComboboxContentList } from './ComboboxContentList-es.js';
import { C as ComboboxContentHeader } from './ComboboxContentHeader-es.js';
import { a as ComboboxContext } from './ComboboxProvider-es.js';
import { u as useRefocusOnActivator_2 } from './useRefocusOnActivator-es.js';
import { u as useFocusTrap_2 } from './useFocusTrap-es.js';
import { C as COMBOBOX_MENU_ID } from './constants-es.js';

var styles = {"content":"QsRc49DHSgA-","hidden":"_7Fd5XGsPpUA-","actions":"yV8-0Hs43J0-","actionPadding":"g3Gdt8jXvFk-","spinning":"dJVYYOaf04E-"};

function useComboboxContent(open, selected) {
    const { shouldScroll } = useContext(ComboboxContext);
    const optionsListRef = useRef(null);
    useEffect(() => {
        var _a;
        if (open && shouldScroll.current && optionsListRef.current) {
            const firstSelected = Array.from((_a = optionsListRef === null || optionsListRef === void 0 ? void 0 : optionsListRef.current) === null || _a === void 0 ? void 0 : _a.children).find(child => {
                if (child instanceof HTMLElement) {
                    return child.dataset.selected === "true";
                }
            });
            scrollToFirstSelected(firstSelected, shouldScroll);
        }
    }, [open, selected]);
    return {
        optionsListRef,
    };
}
function scrollToFirstSelected(firstSelected, shouldScroll) {
    if (firstSelected) {
        firstSelected.scrollIntoView({
            block: "nearest",
        });
        shouldScroll.current = false;
    }
}

const COMBOBOX_OFFSET = 8;
// eslint-disable-next-line max-statements
function useComboboxAccessibility(selectionCallback, filteredOptions, optionsListRef, open, wrapperRef) {
    const { handleClose } = useContext(ComboboxContext);
    const hasOptionsVisible = open && filteredOptions.length > 0;
    const focusedIndex = useRef(null);
    const parentNodeId = useFloatingParentNodeId();
    const nodeId = useFloatingNodeId();
    useRefocusOnActivator_2(open);
    const popperRef = useFocusTrap_2(open);
    const { floatingStyles, update, context } = useFloating({
        nodeId,
        elements: {
            reference: wrapperRef.current,
            floating: popperRef.current,
        },
        open,
        onOpenChange: openState => {
            if (!openState)
                handleClose();
        },
        middleware: [
            autoPlacement({ allowedPlacements: ["bottom-start", "top-start"] }),
            offset(COMBOBOX_OFFSET),
            shift({ padding: COMBOBOX_OFFSET }),
        ],
        placement: "bottom-start",
        whileElementsMounted: autoUpdate,
    });
    const dismiss = useDismiss(context);
    const { getFloatingProps } = useInteractions([dismiss]);
    useEffect(() => {
        focusedIndex.current = null;
        if (open) {
            update === null || update === void 0 ? void 0 : update();
        }
    }, [open, filteredOptions.length, update]);
    useEffect(() => {
        var _a;
        if (open) {
            (_a = popperRef.current) === null || _a === void 0 ? void 0 : _a.addEventListener("keydown", handleContentKeydown);
        }
        return () => {
            var _a;
            (_a = popperRef.current) === null || _a === void 0 ? void 0 : _a.removeEventListener("keydown", handleContentKeydown);
        };
    }, [open, optionsListRef, filteredOptions]);
    function handleContentKeydown(event) {
        var _a;
        if (!hasOptionsVisible)
            return;
        if (event.key === "Enter" || event.key === " ") {
            const activeElementInList = (_a = optionsListRef.current) === null || _a === void 0 ? void 0 : _a.contains(document.activeElement);
            if (!activeElementInList)
                return;
            handleKeyboardSelection(event);
        }
        if (event.key === "ArrowDown") {
            handleKeyboardNavigation(event, 1);
        }
        if (event.key === "ArrowUp") {
            handleKeyboardNavigation(event, -1);
        }
    }
    function handleKeyboardNavigation(event, indexChange) {
        var _a;
        const newIndex = focusedIndex.current === null ? 0 : focusedIndex.current + indexChange;
        if (newIndex < 0 || newIndex >= filteredOptions.length)
            return;
        const optionElement = (_a = optionsListRef.current) === null || _a === void 0 ? void 0 : _a.children[newIndex];
        optionElement === null || optionElement === void 0 ? void 0 : optionElement.focus();
        focusedIndex.current = newIndex;
        event.preventDefault();
        event.stopPropagation();
    }
    function handleKeyboardSelection(event) {
        event.preventDefault();
        event.stopPropagation();
        if (focusedIndex.current !== null) {
            selectionCallback(filteredOptions[focusedIndex.current]);
        }
    }
    return {
        popperRef,
        popperStyles: floatingStyles,
        floatingProps: getFloatingProps(),
        nodeId,
        parentNodeId,
    };
}

function ComboboxContent(props) {
    const optionsExist = props.options.length > 0;
    const { optionsListRef } = useComboboxContent(props.open, props.selected);
    const { popperRef, popperStyles, floatingProps, nodeId, parentNodeId } = useComboboxAccessibility(props.handleSelection, props.options, optionsListRef, props.open, props.wrapperRef);
    const content = (React__default.createElement("div", Object.assign({ ref: popperRef, id: COMBOBOX_MENU_ID, "data-testid": COMBOBOX_MENU_ID, "data-elevation": "elevated", tabIndex: 0, className: classnames(styles.content, {
            [styles.hidden]: !props.open,
        }), style: popperStyles }, floatingProps),
        React__default.createElement(ComboboxContentSearch, { open: props.open, placeholder: props.subjectNoun, searchValue: props.searchValue, setSearchValue: props.setSearchValue, handleSearchChange: props.handleSearchChange }),
        props.multiselect && (optionsExist || props.selected.length > 0) && (React__default.createElement(ComboboxContentHeader, { hasOptionsVisible: optionsExist, subjectNoun: props.subjectNoun, selectedCount: props.selected.length, onClearAll: () => {
                props.selectedStateSetter([]);
            }, onSelectAll: () => {
                props.selectedStateSetter(props.options);
            } })),
        React__default.createElement(ComboboxContentList, { multiselect: props.multiselect, options: props.options, selected: props.selected, optionsListRef: optionsListRef, searchValue: props.searchValue, subjectNoun: props.subjectNoun, loading: props.loading, onLoadMore: props.onLoadMore }),
        props.actionElements && (React__default.createElement("div", { className: styles.actions, role: "group" }, props.actionElements.map((child, index, childrenArray) => (React__default.createElement("div", { key: index, className: classnames({
                [styles.actionPadding]: index === childrenArray.length - 1,
            }) }, child)))))));
    if (parentNodeId) {
        return (React__default.createElement(FloatingTree, null,
            React__default.createElement(FloatingNode, { id: nodeId },
                React__default.createElement(FloatingPortal, null, content))));
    }
    return (globalThis === null || globalThis === void 0 ? void 0 : globalThis.document)
        ? ReactDOM__default.createPortal(content, document.body)
        : content;
}

export { ComboboxContent as C };
