'use strict';

var React = require('react');
var framerMotion = require('framer-motion');
var useFocusTrap = require('./useFocusTrap-cjs.js');
var useRefocusOnActivator = require('./useRefocusOnActivator-cjs.js');
var useOnKeyDown = require('./useOnKeyDown-cjs.js');
var ReactDOM = require('react-dom');
var design = require('@jobber/design');
var useIsMounted = require('./useIsMounted-cjs.js');
var DataList_const = require('./DataList.const-cjs.js');

var styles = {"menu":"e1ztw2-YxtM-","overlay":"uMoOb93Pf1Q-","spinning":"_0wS9DWCNuj4-"};

const variants = {
    hidden: { opacity: 0, y: -10 },
    visible: { opacity: 1, y: 0 },
};
function DataListActionsMenu({ visible = false, position, onRequestClose, children, }) {
    const [ref, setRef] = React.useState();
    const mounted = useIsMounted.useIsMounted_2();
    useRefocusOnActivator.useRefocusOnActivator_2(visible);
    const focusTrapRef = useFocusTrap.useFocusTrap_2(visible);
    useOnKeyDown.useOnKeyDown_2(onRequestClose, "Escape");
    const actionsMenu = (React.createElement(framerMotion.AnimatePresence, null, visible && (React.createElement("div", { ref: focusTrapRef, onClick: handleClick },
        React.createElement(framerMotion.motion.div, { role: "menu", "data-elevation": "elevated", ref: setRef, variants: variants, initial: "hidden", animate: "visible", exit: "hidden", transition: { duration: DataList_const.TRANSITION_DELAY_IN_SECONDS }, className: styles.menu, style: getPositionCssVars(), onClick: onRequestClose }, children),
        React.createElement("button", { type: "button", className: styles.overlay, onClick: onRequestClose, "aria-label": "Close menu" })))));
    return mounted.current
        ? ReactDOM.createPortal(actionsMenu, document.body)
        : actionsMenu;
    function handleClick(event) {
        // Prevent menu from firing the parent's onClick event when it is nested
        // within a clickable list item
        event.stopPropagation();
    }
    function getPositionCssVars() {
        const { posX, posY } = getPosition();
        return {
            "--actions-menu-x": `${posX}px`,
            "--actions-menu-y": `${posY}px`,
        };
    }
    function getPosition() {
        const rect = ref === null || ref === void 0 ? void 0 : ref.getBoundingClientRect();
        const { width = 0, height = 0 } = rect || {};
        const { x, y } = position;
        const xIsOffScreen = x + width > window.innerWidth;
        const yIsOffScreen = y + height > window.innerHeight;
        const xOffSet = x + width - window.innerWidth + design.tokens["space-base"];
        const yOffSet = y + height - window.innerHeight;
        const newPosX = Math.floor(xIsOffScreen ? x - xOffSet : x);
        const newPosY = Math.floor(yIsOffScreen ? y - yOffSet : y);
        return { posX: newPosX, posY: newPosY };
    }
}

exports.DataListActionsMenu = DataListActionsMenu;
