import React, { PropsWithChildren } from "react";
import { ColumnKeys, Direction, Spacing } from "./Flex.types";
interface FlexProps extends PropsWithChildren {
    /**
     * Determine how the children gets laid out
     *
     * **Supported keys**
     * - `"grow"` - Grows to the space available. If all children are set to
     *   grow, then they'll have equal width.
     * - `"shrink"` - Shrinks to the smallest size possible. Normally the size of
     *   the child.
     */
    readonly template: ColumnKeys[];
    /**
     * Adjusts the alignment of the Flex children.
     */
    readonly align?: "start" | "end" | "center";
    /**
     * The spacing between the children.
     *
     *  @default "base"
     */
    readonly gap?: Spacing;
    /**
     * The direction of the content.
     *
     * @default "row"
     */
    readonly direction?: Direction;
}
export declare function Flex({ align, children, direction, gap, template, }: FlexProps): React.JSX.Element;
export {};
