import React__default, { useRef, useState, useEffect, forwardRef } from 'react';
import { o as omit } from '../omit-es.js';
import { D as DatePicker, i as isValid } from '../DatePicker-es.js';
import { k as FormField } from '../FormField-es.js';
import 'classnames';
import '../tslib.es6-es.js';
import 'react-hook-form';
import 'framer-motion';
import '@jobber/design';
import '../Button-es.js';
import { InputText } from '../InputText/index.mjs';
import '../_commonjsHelpers-es.js';
import '../_baseGet-es.js';
import '../isTypedArray-es.js';
import '../isObjectLike-es.js';
import '../identity-es.js';
import '../_getTag-es.js';
import '../isSymbol-es.js';
import '../keysIn-es.js';
import '../_baseAssignValue-es.js';
import '../_baseFlatten-es.js';
import '../_setToString-es.js';
import '../index-es.js';
import 'react-dom';
import 'react-popper';
import '../useRefocusOnActivator-es.js';
import '../Typography-es.js';
import '../AtlantisContext-es.js';
import '../Icon-es.js';
import '../Text-es.js';
import '../useFormFieldFocus-es.js';
import '../InputValidation-es.js';
import '../Spinner-es.js';
import 'react-router-dom';
import '../useSafeLayoutEffect-es.js';

function InputDate$1(inputProps) {
    const formFieldActionsRef = useRef(null);
    return (React__default.createElement(DatePicker, { selected: inputProps.value, onChange: inputProps.onChange, disabled: inputProps.disabled, readonly: inputProps.readonly, fullWidth: !inputProps.inline, minDate: inputProps.minDate, maxDate: inputProps.maxDate, smartAutofocus: false, activator: activatorProps => {
            const { onChange, onClick, value, pickerRef } = activatorProps;
            const newActivatorProps = omit(activatorProps, ["activator"]);
            const [isFocused, setIsFocused] = useState(false);
            const suffix = inputProps.showIcon !== false
                ? {
                    icon: "calendar",
                    ariaLabel: "Show calendar",
                    onClick: !inputProps.disabled && onClick && onClick,
                }
                : undefined;
            // Set form field to formatted date string immediately, to avoid validations
            //  triggering incorrectly when it blurs (to handle the datepicker UI click)
            useEffect(() => {
                var _a;
                value && ((_a = formFieldActionsRef.current) === null || _a === void 0 ? void 0 : _a.setValue(value));
            }, [value]);
            const showEmptyValueLabel = !value && !isFocused;
            return (
            // We prevent the picker from opening on focus for keyboard navigation, so to maintain a good UX for mouse users we want to open the picker on click
            React__default.createElement("div", { onClick: onClick },
                React__default.createElement(FormField, Object.assign({}, newActivatorProps, inputProps, { value: showEmptyValueLabel ? inputProps.emptyValueLabel || "" : value, placeholder: inputProps.placeholder, onChange: (_, event) => {
                        onChange && onChange(event);
                    }, onBlur: () => {
                        var _a;
                        inputProps.onBlur && inputProps.onBlur();
                        activatorProps.onBlur && activatorProps.onBlur();
                        setIsFocused(false);
                        /**
                         * This is an experimental workaround to solve a specific UX problem we have under certain conditions.
                         * When you click to focus InputDate, ReactDatePicker becomes visible. If you delete the current date and blur
                         * the input field by clicking away, ReactDatePicker will automatically set the date to whatever date was
                         * currently selected.
                         *
                         * The above works great and is the expected user experience. ReactDatePicker fills in the empty value for us.
                         *
                         * However, there's a specific scenario where ReactDatePicker isn't visible: when you tab into the input date.
                         * When you tab into it, clear the value, and tab away to blur, ReactDatePicker doesn't automatically fill in
                         * the empty value because it wasn't visible/active.
                         *
                         * To solve this, we need to handle the blur event here and check if the value is empty or invalid. If it is,
                         * we have to call onChange with the original input value which informs ReactDatePicker that is the current value.
                         */
                        if (inputProps.restoreLastValueOnBlur) {
                            if ((!value || !isValid(value)) && inputProps.value) {
                                // @ts-expect-error -- ReactDatePicker types don't include setSelected
                                (_a = pickerRef.current) === null || _a === void 0 ? void 0 : _a.setSelected(inputProps.value);
                            }
                        }
                    }, onFocus: () => {
                        inputProps.onFocus && inputProps.onFocus();
                        activatorProps.onFocus && activatorProps.onFocus();
                        setIsFocused(true);
                    }, onKeyUp: event => {
                        var _a;
                        if (inputProps.showIcon === false &&
                            event.key === "ArrowDown") {
                            (_a = activatorProps.onClick) === null || _a === void 0 ? void 0 : _a.call(activatorProps);
                        }
                    }, actionsRef: formFieldActionsRef, suffix: suffix }))));
        } }));
}

/**
 * Combines the actions on the InputDate such as onChange, onFocus, onBlur to forward event handler passed to the InputDate component to the DatePicker component.
 * DO not repeat this pattern. We are doing this as a proof of concept relating to the refactoring of Form inputs to see what can be removed.
 */
function useInputDateActivatorActions({ onChange, onBlur, onFocus, }) {
    const [isFocused, setIsFocused] = useState(false);
    function handleChange(_, event) {
        onChange === null || onChange === void 0 ? void 0 : onChange(event);
    }
    function handleFocus(event) {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
        setIsFocused(true);
    }
    function handleBlur(event) {
        setIsFocused(false);
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    }
    return {
        handleBlur,
        handleChange,
        handleFocus,
        isFocused,
    };
}

const InputDateRebuilt = forwardRef((props, forwardedRef) => {
    const { onChange } = props;
    return (React__default.createElement(DatePicker, { selected: props.value, onChange: newValue => {
            onChange(newValue);
        }, disabled: props.disabled, readonly: props.readOnly, fullWidth: !props.inline, minDate: props.minDate, maxDate: props.maxDate, smartAutofocus: false, activator: InputDateActivator }));
    function InputDateActivator(activatorProps) {
        const { onClick, value } = activatorProps;
        const { handleChange, handleFocus, handleBlur, isFocused } = useInputDateActivatorActions({
            onChange: activatorProps.onChange,
            onFocus: event => {
                var _a, _b;
                (_a = props.onFocus) === null || _a === void 0 ? void 0 : _a.call(props, event);
                (_b = activatorProps.onFocus) === null || _b === void 0 ? void 0 : _b.call(activatorProps);
            },
            onBlur: event => {
                var _a, _b;
                (_a = props.onBlur) === null || _a === void 0 ? void 0 : _a.call(props, event);
                (_b = activatorProps.onBlur) === null || _b === void 0 ? void 0 : _b.call(activatorProps);
            },
        });
        const suffix = props.showIcon !== false
            ? {
                icon: "calendar",
                ariaLabel: "Show calendar",
                onClick: !props.disabled && onClick && onClick,
            }
            : undefined;
        const showEmptyValueLabel = !value && !isFocused;
        return (
        // We prevent the picker from opening on focus for keyboard navigation, so to maintain a good UX for mouse users we want to open the picker on click
        React__default.createElement("div", { onClick: onClick },
            React__default.createElement(InputText, { "aria-describedby": activatorProps.ariaDescribedBy, "aria-invalid": activatorProps.ariaInvalid === "true" ? true : false, "aria-labelledby": activatorProps.ariaLabelledBy, "aria-required": activatorProps.ariaRequired === "true" ? true : false, id: activatorProps.id, disabled: props.disabled, error: props.error, readOnly: props.readOnly, placeholder: props.placeholder, size: props.size, inline: props.inline, align: props.align, description: props.description, invalid: props.invalid, name: props.name, version: 2, value: showEmptyValueLabel ? props.emptyValueLabel || "" : value || "", ref: forwardedRef, suffix: suffix, onFocus: handleFocus, onBlur: handleBlur, onKeyDown: event => {
                    var _a, _b;
                    if (props.showIcon === false && event.key === "ArrowDown") {
                        (_a = activatorProps.onClick) === null || _a === void 0 ? void 0 : _a.call(activatorProps);
                    }
                    (_b = props.onKeyDown) === null || _b === void 0 ? void 0 : _b.call(props, event);
                }, onChange: handleChange })));
    }
});
InputDateRebuilt.displayName = "InputDateRebuilt";

function isNewInputDateProps(props) {
    return props.version === 2;
}
const InputDate = forwardRef(function InputDateShim(props, ref) {
    if (isNewInputDateProps(props)) {
        return React__default.createElement(InputDateRebuilt, Object.assign({}, props, { ref: ref }));
    }
    else {
        return React__default.createElement(InputDate$1, Object.assign({}, props));
    }
});

export { InputDate };
