'use strict';

var React = require('react');
var FormField = require('../FormField-cjs.js');
require('classnames');
var tslib_es6 = require('../tslib.es6-cjs.js');
require('react-hook-form');
require('framer-motion');
require('@jobber/design');
require('../Button-cjs.js');
var omit = require('../omit-cjs.js');
require('../Icon-cjs.js');
require('../Text-cjs.js');
require('../Typography-cjs.js');
require('../useFormFieldFocus-cjs.js');
require('../InputValidation-cjs.js');
require('../Spinner-cjs.js');
require('react-router-dom');
require('../_commonjsHelpers-cjs.js');
require('../_baseGet-cjs.js');
require('../isTypedArray-cjs.js');
require('../isObjectLike-cjs.js');
require('../identity-cjs.js');
require('../_getTag-cjs.js');
require('../isSymbol-cjs.js');
require('../keysIn-cjs.js');
require('../_baseAssignValue-cjs.js');
require('../_baseFlatten-cjs.js');
require('../_setToString-cjs.js');

const validationMessage = "Please enter a valid email";

function InputEmail$1(props) {
    const { validations } = props;
    return (React.createElement(FormField.FormField, Object.assign({}, props, { type: "email", validations: Object.assign(Object.assign({}, validations), { validate: checkForValidEmail }) })));
    function checkForValidEmail(value) {
        const emailRegex = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
        if (!value) {
            return true;
        }
        if (!value.match(emailRegex)) {
            return validationMessage;
        }
        return true;
    }
}

function useInputEmailActions({ onChange, inputRef, onEnter, onFocus, onBlur, onKeyDown, }) {
    function handleClear() {
        var _a;
        handleBlur();
        onChange === null || onChange === void 0 ? void 0 : onChange("");
        (_a = inputRef === null || inputRef === void 0 ? void 0 : inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    }
    function handleChange(event) {
        const newValue = event.currentTarget.value;
        onChange === null || onChange === void 0 ? void 0 : onChange(newValue, event);
    }
    function handleKeyDown(event) {
        onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(event);
        if (!onEnter)
            return;
        if (event.key !== "Enter")
            return;
        if (event.shiftKey || event.ctrlKey)
            return;
        event.preventDefault();
        onEnter === null || onEnter === void 0 ? void 0 : onEnter(event);
    }
    function handleFocus(event) {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    }
    function handleBlur(event) {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    }
    return {
        handleClear,
        handleChange,
        handleKeyDown,
        handleFocus,
        handleBlur,
    };
}

function useInputEmailFormField(_a) {
    var { id, name, disabled, autofocus, description, inline, value, handleChange, handleBlur, handleFocus, handleKeyDown, error } = _a, rest = tslib_es6.__rest(_a, ["id", "name", "disabled", "autofocus", "description", "inline", "value", "handleChange", "handleBlur", "handleFocus", "handleKeyDown", "error"]);
    const descriptionIdentifier = `descriptionUUID--${id}`;
    const fieldProps = Object.assign(Object.assign(Object.assign({}, rest), { id,
        name,
        disabled, autoFocus: autofocus, onChange: handleChange, onBlur: handleBlur, onFocus: handleFocus, onKeyDown: handleKeyDown, value, invalid: error || rest.invalid ? "true" : undefined }), (description &&
        !inline && { "aria-describedby": descriptionIdentifier }));
    return { fieldProps, descriptionIdentifier };
}

const InputEmailRebuilt = React.forwardRef(function InputEmailInternal(props, ref) {
    var _a, _b, _c;
    const id = React.useId();
    const inputRef = (_a = ref) !== null && _a !== void 0 ? _a : React.useRef(null);
    const wrapperRef = React.useRef(null);
    const { inputStyle } = FormField.useFormFieldWrapperStyles({
        size: props.size,
        inline: props.inline,
        align: props.align,
        type: "email",
        value: props.value,
        invalid: props.invalid,
        error: props.error,
        maxLength: props.maxLength,
        disabled: props.disabled,
        placeholder: props.placeholder,
    });
    const { name } = FormField.useAtlantisFormFieldName({
        nameProp: props.name,
        id,
    });
    const { handleChange, handleBlur, handleFocus, handleKeyDown, handleClear } = useInputEmailActions({
        onChange: props.onChange,
        onBlur: props.onBlur,
        onFocus: props.onFocus,
        onKeyDown: props.onKeyDown,
        onEnter: props.onEnter,
        inputRef,
    });
    const inputProps = omit.omit(props, [
        "placeholder",
        "onChange",
        "onBlur",
        "onFocus",
        "onEnter",
        "size",
        "prefix",
        "suffix",
        "version",
    ]);
    const { fieldProps, descriptionIdentifier } = useInputEmailFormField(Object.assign(Object.assign({}, inputProps), { id,
        name,
        handleChange,
        handleBlur,
        handleFocus,
        handleKeyDown }));
    return (React.createElement(FormField.FormFieldWrapper, { error: props.error || "", invalid: props.invalid, identifier: props.identifier || id, descriptionIdentifier: descriptionIdentifier, size: props.size, inline: props.inline, align: props.align, prefix: props.prefix, suffix: props.suffix, description: props.description, clearable: (_b = props.clearable) !== null && _b !== void 0 ? _b : "never", onClear: handleClear, wrapperRef: wrapperRef, maxLength: props.maxLength, disabled: props.disabled, type: "email", value: props.value, placeholder: props.placeholder, autofocus: props.autoFocus, name: name },
        React.createElement("input", Object.assign({}, fieldProps, { ref: inputRef, type: "email", className: inputStyle, value: props.value, "data-testid": "ATL-InputEmail-input" })),
        React.createElement(FormField.FormFieldPostFix, { variation: "spinner", visible: (_c = props.loading) !== null && _c !== void 0 ? _c : false }),
        props.children));
});

function isNewInputEmailProps(props) {
    return props.version === 2;
}
const InputEmail = React.forwardRef(function InputEmailShim(props, ref) {
    if (isNewInputEmailProps(props)) {
        return (React.createElement(InputEmailRebuilt, Object.assign({}, props, { ref: ref })));
    }
    else {
        return React.createElement(InputEmail$1, Object.assign({}, props));
    }
});

exports.InputEmail = InputEmail;
