import React__default, { forwardRef, useId, useRef } from 'react';
import { k as FormField, j as useFormFieldWrapperStyles, b as useAtlantisFormFieldName, f as FormFieldWrapper, l as FormFieldPostFix } from '../FormField-es.js';
import 'classnames';
import { _ as __rest } from '../tslib.es6-es.js';
import 'react-hook-form';
import 'framer-motion';
import '@jobber/design';
import '../Button-es.js';
import { o as omit } from '../omit-es.js';
import '../Icon-es.js';
import '../Text-es.js';
import '../Typography-es.js';
import '../useFormFieldFocus-es.js';
import '../InputValidation-es.js';
import '../Spinner-es.js';
import 'react-router-dom';
import '../_commonjsHelpers-es.js';
import '../_baseGet-es.js';
import '../isTypedArray-es.js';
import '../isObjectLike-es.js';
import '../identity-es.js';
import '../_getTag-es.js';
import '../isSymbol-es.js';
import '../keysIn-es.js';
import '../_baseAssignValue-es.js';
import '../_baseFlatten-es.js';
import '../_setToString-es.js';

const validationMessage = "Please enter a valid email";

function InputEmail$1(props) {
    const { validations } = props;
    return (React__default.createElement(FormField, Object.assign({}, props, { type: "email", validations: Object.assign(Object.assign({}, validations), { validate: checkForValidEmail }) })));
    function checkForValidEmail(value) {
        const emailRegex = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
        if (!value) {
            return true;
        }
        if (!value.match(emailRegex)) {
            return validationMessage;
        }
        return true;
    }
}

function useInputEmailActions({ onChange, inputRef, onEnter, onFocus, onBlur, onKeyDown, }) {
    function handleClear() {
        var _a;
        handleBlur();
        onChange === null || onChange === void 0 ? void 0 : onChange("");
        (_a = inputRef === null || inputRef === void 0 ? void 0 : inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    }
    function handleChange(event) {
        const newValue = event.currentTarget.value;
        onChange === null || onChange === void 0 ? void 0 : onChange(newValue, event);
    }
    function handleKeyDown(event) {
        onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(event);
        if (!onEnter)
            return;
        if (event.key !== "Enter")
            return;
        if (event.shiftKey || event.ctrlKey)
            return;
        event.preventDefault();
        onEnter === null || onEnter === void 0 ? void 0 : onEnter(event);
    }
    function handleFocus(event) {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    }
    function handleBlur(event) {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    }
    return {
        handleClear,
        handleChange,
        handleKeyDown,
        handleFocus,
        handleBlur,
    };
}

function useInputEmailFormField(_a) {
    var { id, name, disabled, autofocus, description, inline, value, handleChange, handleBlur, handleFocus, handleKeyDown, error } = _a, rest = __rest(_a, ["id", "name", "disabled", "autofocus", "description", "inline", "value", "handleChange", "handleBlur", "handleFocus", "handleKeyDown", "error"]);
    const descriptionIdentifier = `descriptionUUID--${id}`;
    const fieldProps = Object.assign(Object.assign(Object.assign({}, rest), { id,
        name,
        disabled, autoFocus: autofocus, onChange: handleChange, onBlur: handleBlur, onFocus: handleFocus, onKeyDown: handleKeyDown, value, invalid: error || rest.invalid ? "true" : undefined }), (description &&
        !inline && { "aria-describedby": descriptionIdentifier }));
    return { fieldProps, descriptionIdentifier };
}

const InputEmailRebuilt = forwardRef(function InputEmailInternal(props, ref) {
    var _a, _b, _c;
    const id = useId();
    const inputRef = (_a = ref) !== null && _a !== void 0 ? _a : useRef(null);
    const wrapperRef = useRef(null);
    const { inputStyle } = useFormFieldWrapperStyles({
        size: props.size,
        inline: props.inline,
        align: props.align,
        type: "email",
        value: props.value,
        invalid: props.invalid,
        error: props.error,
        maxLength: props.maxLength,
        disabled: props.disabled,
        placeholder: props.placeholder,
    });
    const { name } = useAtlantisFormFieldName({
        nameProp: props.name,
        id,
    });
    const { handleChange, handleBlur, handleFocus, handleKeyDown, handleClear } = useInputEmailActions({
        onChange: props.onChange,
        onBlur: props.onBlur,
        onFocus: props.onFocus,
        onKeyDown: props.onKeyDown,
        onEnter: props.onEnter,
        inputRef,
    });
    const inputProps = omit(props, [
        "placeholder",
        "onChange",
        "onBlur",
        "onFocus",
        "onEnter",
        "size",
        "prefix",
        "suffix",
        "version",
    ]);
    const { fieldProps, descriptionIdentifier } = useInputEmailFormField(Object.assign(Object.assign({}, inputProps), { id,
        name,
        handleChange,
        handleBlur,
        handleFocus,
        handleKeyDown }));
    return (React__default.createElement(FormFieldWrapper, { error: props.error || "", invalid: props.invalid, identifier: props.identifier || id, descriptionIdentifier: descriptionIdentifier, size: props.size, inline: props.inline, align: props.align, prefix: props.prefix, suffix: props.suffix, description: props.description, clearable: (_b = props.clearable) !== null && _b !== void 0 ? _b : "never", onClear: handleClear, wrapperRef: wrapperRef, maxLength: props.maxLength, disabled: props.disabled, type: "email", value: props.value, placeholder: props.placeholder, autofocus: props.autoFocus, name: name },
        React__default.createElement("input", Object.assign({}, fieldProps, { ref: inputRef, type: "email", className: inputStyle, value: props.value, "data-testid": "ATL-InputEmail-input" })),
        React__default.createElement(FormFieldPostFix, { variation: "spinner", visible: (_c = props.loading) !== null && _c !== void 0 ? _c : false }),
        props.children));
});

function isNewInputEmailProps(props) {
    return props.version === 2;
}
const InputEmail = forwardRef(function InputEmailShim(props, ref) {
    if (isNewInputEmailProps(props)) {
        return (React__default.createElement(InputEmailRebuilt, Object.assign({}, props, { ref: ref })));
    }
    else {
        return React__default.createElement(InputEmail$1, Object.assign({}, props));
    }
});

export { InputEmail };
