import React__default, { useEffect } from 'react';
import { a as useInternalChipDismissibleInput, d as useScrollToActive, b as useInView, c as useRepositionMenu, u as useInternalChipDismissible } from './useScrollToActive-es.js';
import './isObjectLike-es.js';
import '@jobber/design';
import 'react-popper';
import classnames from 'classnames';
import { u as useSafeLayoutEffect_1 } from './useSafeLayoutEffect-es.js';
import { T as Text } from './Text-es.js';
import { B as Button } from './Button-es.js';
import { S as Spinner } from './Spinner-es.js';
import { C as ChipNamespace, I as InternalChipButton } from './Chip-es.js';
import './tslib.es6-es.js';

function InternalChip({ label, active = false, disabled = false, invalid = false, prefix, suffix, tabIndex, ariaLabel, onClick, onKeyDown, }) {
    return (React__default.createElement(ChipNamespace, { disabled: disabled, invalid: invalid, onKeyDown: onKeyDown, testID: "ATL-InternalChip", ariaLabel: ariaLabel, tabIndex: tabIndex, variation: active ? "base" : "subtle", role: tabIndex !== undefined ? "option" : undefined, onClick: onClick ? (_, ev) => onClick(ev) : undefined, label: label },
        prefix && React__default.createElement(ChipNamespace.Prefix, null, prefix),
        suffix && React__default.createElement(ChipNamespace.Suffix, null, suffix)));
}

var styles = {"wrapper":"XRnU90M2-fs-","input":"Dq-yFHd1zK0-","menu":"F7CpurjKzBI-","menuList":"J8USVG1tjPs-","menuListOption":"_9SAK31TqNDY-","loadingIndicator":"s5vFJVv0t0Q-","activeOption":"_8d0w-JzgzS4-","spinning":"hDJGLX6kE-U-"};

function InternalChipDismissibleInput(props) {
    const { activator = React__default.createElement(Button, { icon: "add", type: "secondary", ariaLabel: "Add" }), attachTo, isLoadingMore = false, onLoadMore, options, } = props;
    const { activeIndex, allOptions, hasAvailableOptions, inputRef, menuId, menuOpen, searchValue, showInput, generateDescendantId, handleBlur, handleFocus, handleSearchChange, handleCancelBlur, handleEnableBlur, handleSetActiveOnMouseOver, handleKeyDown, handleSelectOption, handleShowInput, handleDebouncedSearch, } = useInternalChipDismissibleInput(props);
    const menuRef = useScrollToActive(activeIndex);
    const { ref: visibleChildRef, isInView } = useInView();
    const { styles: popperStyles, attributes, update, setPositionedElementRef, } = useRepositionMenu(attachTo);
    useSafeLayoutEffect_1(() => {
        update === null || update === void 0 ? void 0 : update();
    }, [allOptions, menuOpen, update, options]);
    useEffect(() => {
        handleDebouncedSearch(searchValue, options);
        return handleDebouncedSearch.cancel;
    }, [searchValue, options]);
    useEffect(() => {
        isInView && onLoadMore && onLoadMore(searchValue);
    }, [isInView]);
    if (!showInput) {
        return React__default.cloneElement(activator, { onClick: handleShowInput });
    }
    const shouldShowMenu = menuOpen && (hasAvailableOptions || isLoadingMore);
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement("input", { ref: inputRef, className: styles.input, type: "text", role: "combobox", "aria-label": "Press up and down arrow to cycle through the options or type to narrow down the results", "aria-autocomplete": "list", "aria-owns": menuId, "aria-expanded": shouldShowMenu, "aria-activedescendant": generateDescendantId(activeIndex), value: searchValue, onChange: handleSearchChange, onKeyDown: handleKeyDown, onBlur: () => setTimeout(handleBlur, 200), onFocus: handleFocus, autoFocus: true }),
        shouldShowMenu && (React__default.createElement("div", Object.assign({ ref: setPositionedElementRef, className: styles.menu, style: popperStyles.popper }, attributes.popper),
            React__default.createElement("div", { ref: menuRef, role: "listbox", id: menuId, className: styles.menuList, "data-testid": "chip-menu" },
                allOptions.map((option, i) => (React__default.createElement("button", { key: option.value, role: "option", type: "button", id: generateDescendantId(i), className: classnames(styles.menuListOption, {
                        [styles.activeOption]: activeIndex === i,
                    }), onClick: () => handleSelectOption(option), onMouseEnter: handleSetActiveOnMouseOver(i), onMouseDown: handleCancelBlur, onMouseUp: handleEnableBlur },
                    React__default.createElement("span", { "aria-hidden": true }, option.prefix),
                    React__default.createElement(Text, null, option.label)))),
                React__default.createElement("div", { ref: visibleChildRef }),
                isLoadingMore && (React__default.createElement("div", { className: styles.loadingIndicator },
                    React__default.createElement(Spinner, { size: "small", inline: true }))))))));
}

function InternalChipDismissible(props) {
    const { availableChipOptions, ref: wrapperRef, sortedVisibleChipOptions, handleChipAdd, handleChipClick, handleChipKeyDown, handleChipRemove, handleCustomAdd, handleWrapperKeyDown, } = useInternalChipDismissible(props);
    return (React__default.createElement("div", { ref: wrapperRef, className: styles.wrapper, "data-testid": "dismissible-chips", onKeyDown: handleWrapperKeyDown, role: "listbox" },
        sortedVisibleChipOptions.map(chip => (React__default.createElement(InternalChip, Object.assign({ key: chip.value }, chip, { onKeyDown: handleChipKeyDown(chip.value), onClick: handleChipClick(chip.value), ariaLabel: `${chip.label}. Press delete or backspace to remove ${chip.label}`, tabIndex: 0, suffix: React__default.createElement(InternalChipButton, { icon: "remove", invalid: chip.invalid, disabled: chip.disabled, label: chip.label, onClick: handleChipRemove(chip.value) }) })))),
        React__default.createElement(InternalChipDismissibleInput, { activator: props.activator, attachTo: wrapperRef, isLoadingMore: props.isLoadingMore, options: availableChipOptions, onOptionSelect: handleChipAdd, onCustomOptionSelect: handleCustomAdd, onSearch: props.onSearch, onLoadMore: props.onLoadMore, onlyShowMenuOnSearch: props.onlyShowMenuOnSearch, autoSelectOnClickOutside: props.autoSelectOnClickOutside })));
}

export { InternalChipDismissible as I, InternalChip as a };
