import React__default, { useState, useRef, useId } from 'react';
import classnames from 'classnames';
import { AnimatePresence, motion } from 'framer-motion';
import { u as useOnKeyDown_2 } from './useOnKeyDown-es.js';
import { u as useRefocusOnActivator_2 } from './useRefocusOnActivator-es.js';
import { usePopper } from 'react-popper';
import { u as useIsMounted_2 } from './useIsMounted-es.js';
import ReactDOM__default from 'react-dom';
import { u as useFocusTrap_2 } from './useFocusTrap-es.js';
import { B as Button } from './Button-es.js';
import { T as Typography } from './Typography-es.js';
import { I as Icon } from './Icon-es.js';
import { f as formFieldFocusAttribute } from './useFormFieldFocus-es.js';

var useWindowDimensions$1 = {};

Object.defineProperty(useWindowDimensions$1, "__esModule", { value: true });
var useWindowDimensions_2 = useWindowDimensions$1.useWindowDimensions = useWindowDimensions;
const react_1 = React__default;
function getWindowDimensions() {
    if (!(globalThis === null || globalThis === void 0 ? void 0 : globalThis.document)) {
        return {
            width: 0,
            height: 0,
        };
    }
    const { innerWidth: width, innerHeight: height } = window;
    return {
        width,
        height,
    };
}
function useWindowDimensions() {
    const [windowDimensions, setWindowDimensions] = (0, react_1.useState)(getWindowDimensions());
    (0, react_1.useEffect)(() => {
        function handleResize() {
            setWindowDimensions(getWindowDimensions());
        }
        window === null || window === void 0 ? void 0 : window.addEventListener("resize", handleResize);
        return () => window === null || window === void 0 ? void 0 : window.removeEventListener("resize", handleResize);
    }, []);
    return windowDimensions;
}

var styles = {"wrapper":"fpi0W91w2ag-","popperContainer":"pyIy8jHif3g-","menu":"-DayvgvIcVo-","section":"X0W9r8kjA6Q-","sectionHeader":"Bq7pLWj3jm4-","action":"M1BgN-oCmKw-","destructive":"U9ihZZavz9w-","overlay":"_7we5hh6kYs8-","fullWidth":"_5OJ7B6mFcwk-","screenReaderOnly":"Bzvkz60bwWE-","spinning":"_0-VzuzHdi8o-"};

const SMALL_SCREEN_BREAKPOINT = 490;
const MENU_OFFSET = 6;
const variation = {
    overlayStartStop: { opacity: 0 },
    startOrStop: (placement) => {
        let y = 10;
        if (placement === null || placement === void 0 ? void 0 : placement.includes("bottom"))
            y *= -1;
        if (window.innerWidth < SMALL_SCREEN_BREAKPOINT)
            y = 150;
        return { opacity: 0, y };
    },
    done: { opacity: 1, y: 0 },
};
// eslint-disable-next-line max-statements
function Menu({ activator, items, UNSAFE_className, UNSAFE_style, }) {
    var _a;
    const [visible, setVisible] = useState(false);
    const popperRef = useRef(null);
    const { width } = useWindowDimensions_2();
    const buttonID = useId();
    const menuID = useId();
    const fullWidth = ((_a = activator === null || activator === void 0 ? void 0 : activator.props) === null || _a === void 0 ? void 0 : _a.fullWidth) || false;
    const wrapperClasses = classnames(styles.wrapper, {
        [styles.fullWidth]: fullWidth,
    });
    useOnKeyDown_2(handleKeyboardShortcut, ["Escape"]);
    // useRefocusOnActivator must come before useFocusTrap for them both to work
    useRefocusOnActivator_2(visible);
    const menuRef = useFocusTrap_2(visible);
    const [popperElement, setPopperElement] = useState(null);
    const { styles: popperStyles, attributes, state, } = usePopper(popperRef.current, popperElement, {
        placement: "bottom-start",
        strategy: "fixed",
        modifiers: [
            {
                name: "flip",
                options: {
                    flipVariations: true,
                },
            },
            {
                name: "offset",
                options: {
                    offset: [0, MENU_OFFSET],
                },
            },
        ],
    });
    const positionAttributes = width >= SMALL_SCREEN_BREAKPOINT
        ? Object.assign(Object.assign({}, attributes.popper), { style: popperStyles.popper }) : {};
    if (!activator) {
        activator = (React__default.createElement(Button, { fullWidth: true, label: "More Actions", icon: "more", type: "secondary" }));
    }
    return (React__default.createElement("div", { className: wrapperClasses, onClick: handleParentClick },
        React__default.createElement("div", { ref: popperRef }, React__default.cloneElement(activator, {
            onClick: toggle(activator.props.onClick),
            id: buttonID,
            ariaControls: menuID,
            ariaExpanded: visible,
            ariaHaspopup: true,
        })),
        React__default.createElement(MenuPortal, null,
            React__default.createElement(AnimatePresence, null, visible && (React__default.createElement(React__default.Fragment, null,
                React__default.createElement(motion.div, { className: styles.overlay, onClick: toggle(), variants: variation, initial: "overlayStartStop", animate: "done", exit: "overlayStartStop", transition: {
                        type: "tween",
                        duration: 0.15,
                    } }),
                React__default.createElement("div", Object.assign({ ref: setPopperElement, className: styles.popperContainer }, positionAttributes, formFieldFocusAttribute), items.length > 0 && (React__default.createElement(motion.div, { className: classnames(styles.menu, UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.menu), role: "menu", "data-elevation": "elevated", "aria-labelledby": buttonID, id: menuID, onClick: hide, variants: variation, initial: "startOrStop", animate: "done", exit: "startOrStop", custom: state === null || state === void 0 ? void 0 : state.placement, ref: menuRef, transition: {
                        type: "tween",
                        duration: 0.25,
                    }, style: UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.menu }, items.map((item, key) => (React__default.createElement("div", { key: key, className: styles.section },
                    item.header && (React__default.createElement(SectionHeader, { text: item.header, UNSAFE_style: UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.header, UNSAFE_className: UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.header })),
                    item.actions.map(action => (React__default.createElement(Action, Object.assign({ UNSAFE_style: UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.action, UNSAFE_className: UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.action, sectionLabel: item.header, key: action.label }, action))))))))))))))));
    function toggle(callbackPassthrough) {
        return (event) => {
            setVisible(!visible);
            callbackPassthrough && callbackPassthrough(event);
        };
    }
    function hide() {
        setVisible(false);
    }
    function handleKeyboardShortcut(event) {
        const { key } = event;
        if (!visible)
            return;
        event.preventDefault();
        event.stopPropagation();
        key === "Escape" && hide();
    }
    function handleParentClick(event) {
        // Since the menu is being rendered within the same parent as the activator,
        // we need to stop the click event from bubbling up. If the Menu component
        // gets added within a parent that has a click handler, any click on the
        // menu will trigger the parent's click handler.
        event.stopPropagation();
    }
}
function SectionHeader({ text, UNSAFE_style, UNSAFE_className, }) {
    return (React__default.createElement("div", { className: classnames(styles.sectionHeader, UNSAFE_className), "aria-hidden": true, style: UNSAFE_style },
        React__default.createElement(Typography, { element: "h6", size: "base", textColor: "textSecondary", fontWeight: "regular", textCase: "none" }, text)));
}
function Action({ label, sectionLabel, icon, iconColor, destructive, UNSAFE_style, UNSAFE_className, onClick, }) {
    const actionButtonRef = useRef();
    const buttonClasses = classnames(styles.action, {
        [styles.destructive]: destructive,
    });
    return (React__default.createElement("button", { role: "menuitem", type: "button", className: classnames(buttonClasses, UNSAFE_className), key: label, onClick: onClick, ref: actionButtonRef, style: UNSAFE_style },
        icon && (React__default.createElement("div", null,
            React__default.createElement(Icon, { color: destructive ? "destructive" : iconColor, name: icon }))),
        React__default.createElement(Typography, { element: "span", fontWeight: "semiBold", textColor: "text" },
            sectionLabel && (React__default.createElement("span", { className: styles.screenReaderOnly }, sectionLabel)),
            label)));
}
function MenuPortal({ children }) {
    const mounted = useIsMounted_2();
    if (!(mounted === null || mounted === void 0 ? void 0 : mounted.current)) {
        return null;
    }
    return ReactDOM__default.createPortal(children, document.body);
}

export { Menu as M };
