import React, { CSSProperties, ReactElement } from "react";
import { IconColorNames, IconNames } from "@jobber/design";
export interface MenuProps {
    /**
     * Custom menu activator. If this is not provided a default [… More] will be used.
     */
    readonly activator?: ReactElement;
    /**
     * Collection of action items.
     */
    readonly items: SectionProps[];
    /**
     * **Use at your own risk:** Custom class names for specific elements. This should only be used as a
     * **last resort**. Using this may result in unexpected side effects.
     * More information in the [Customizing components Guide](https://atlantis.getjobber.com/guides/customizing-components).
     */
    readonly UNSAFE_className?: {
        menu?: string;
        header?: string;
        action?: string;
    };
    /**
     * **Use at your own risk:** Custom style for specific elements. This should only be used as a
     * **last resort**. Using this may result in unexpected side effects.
     * More information in the [Customizing components Guide](https://atlantis.getjobber.com/guides/customizing-components).
     */
    readonly UNSAFE_style?: {
        menu?: CSSProperties;
        header?: CSSProperties;
        action?: CSSProperties;
    };
}
export interface SectionProps {
    /**
     * Defines the section header to further explain the group of actions.
     */
    header?: string;
    /**
     * List of actions.
     */
    actions: ActionProps[];
}
export declare function Menu({ activator, items, UNSAFE_className, UNSAFE_style, }: MenuProps): React.JSX.Element;
export interface ActionProps {
    /**
     * Action label
     */
    readonly label: string;
    /**
     * Parent Section Label
     */
    readonly sectionLabel?: string;
    /**
     * Visual cue for the action label
     */
    readonly icon?: IconNames;
    /**
     * Color for the icon. Defaults to "icon".
     */
    readonly iconColor?: IconColorNames;
    /**
     * Visual style for the action button
     */
    readonly destructive?: boolean;
    /**
     * Inline style overrides for the action button
     */
    readonly UNSAFE_style?: CSSProperties;
    /**
     * Style class overrides for the action button
     */
    readonly UNSAFE_className?: string;
    /**
     * Callback when an action gets clicked
     */
    onClick?(event: React.MouseEvent<HTMLButtonElement>): void;
}
