'use strict';

var React = require('react');
var ReactDOM = require('react-dom');
var classnames = require('classnames');
var framerMotion = require('framer-motion');
var useRefocusOnActivator = require('../useRefocusOnActivator-cjs.js');
var useOnKeyDown = require('../useOnKeyDown-cjs.js');
var useFocusTrap = require('../useFocusTrap-cjs.js');
var Heading = require('../Heading-cjs.js');
var Button = require('../Button-cjs.js');
var ButtonDismiss = require('../ButtonDismiss-cjs.js');
var noop = require('../noop-cjs.js');
var floatingUi_react = require('../floating-ui.react-cjs.js');
var identity = require('../identity-cjs.js');
var AtlantisPortalContent = require('../AtlantisPortalContent-cjs.js');
require('../Typography-cjs.js');
require('react-router-dom');
require('../tslib.es6-cjs.js');
require('../Icon-cjs.js');
require('@jobber/design');
require('../_commonjsHelpers-cjs.js');
require('../isTypedArray-cjs.js');
require('../isObjectLike-cjs.js');
require('../AtlantisThemeContext-cjs.js');
require('../_baseAssignValue-cjs.js');
require('../_baseFor-cjs.js');
require('../keysIn-cjs.js');
require('../_isIterateeCall-cjs.js');
require('../_setToString-cjs.js');

var styles$1 = {"container":"y3M-9xoEnk0-","overlay":"zkyJp1mib-U-","modal":"gMPgiggaud8-","header":"_5sBzUnyOqD0-","closeButton":"_4gw63G7IYG0-","actionBar":"cwVJrrJkNDg-","leftAction":"MkD4pNUKeAA-","rightAction":"C-yC8JKpQLg-","spinning":"_7hYqr6OrfHs-"};

var sizes = {"small":"BSZvIAUzFEU-","large":"-ydIALYVvGg-","spinning":"_10FfgKITqY0-"};

function ModalLegacy({ open = false, title, size, dismissible = true, children, primaryAction, secondaryAction, tertiaryAction, onRequestClose, }) {
    const modalClassName = classnames(styles$1.modal, size && sizes[size]);
    useRefocusOnActivator.useRefocusOnActivator_2(open);
    const modalRef = useFocusTrap.useFocusTrap_2(open);
    useOnKeyDown.useOnKeyDown_2(handleRequestClose, "Escape");
    const template = (React.createElement(framerMotion.AnimatePresence, null, open && (React.createElement("div", { ref: modalRef, role: "dialog", className: styles$1.container, tabIndex: 0 },
        React.createElement(framerMotion.motion.div, { key: styles$1.overlay, className: styles$1.overlay, onClick: onRequestClose, initial: { opacity: 0 }, animate: { opacity: 0.8 }, exit: { opacity: 0 }, transition: { duration: 0.2 } }),
        React.createElement(framerMotion.motion.div, { key: styles$1.modal, className: modalClassName, initial: { scale: 0.9, opacity: 0 }, animate: { scale: 1, opacity: 1 }, exit: { scale: 0.9, opacity: 0 }, transition: {
                duration: 0.2,
                ease: "easeInOut",
            } },
            title != undefined && (React.createElement(Header, { title: title, dismissible: dismissible, onRequestClose: onRequestClose })),
            children,
            React.createElement(Actions, { primary: primaryAction, secondary: secondaryAction, tertiary: tertiaryAction }))))));
    return (globalThis === null || globalThis === void 0 ? void 0 : globalThis.document)
        ? ReactDOM.createPortal(template, document.body)
        : template;
    function handleRequestClose() {
        if (open && onRequestClose) {
            onRequestClose();
        }
    }
}
function Header({ title, dismissible, onRequestClose }) {
    return (React.createElement("div", { className: styles$1.header, "data-testid": "modal-header" },
        React.createElement(Heading.Heading, { level: 2 }, title),
        dismissible && (React.createElement("div", { className: styles$1.closeButton },
            React.createElement(ButtonDismiss.ButtonDismiss, { onClick: onRequestClose, ariaLabel: "Close modal" })))));
}
function Actions({ primary, secondary, tertiary }) {
    const shouldShow = primary != undefined || secondary != undefined || tertiary != undefined;
    if (secondary != undefined) {
        secondary = Object.assign({ type: "primary", variation: "subtle" }, secondary);
    }
    if (tertiary != undefined) {
        tertiary = Object.assign({ type: "secondary", variation: "destructive" }, tertiary);
    }
    return (React.createElement(React.Fragment, null, shouldShow && (React.createElement("div", { className: styles$1.actionBar },
        React.createElement("div", { className: styles$1.rightAction },
            primary && React.createElement(Button.Button, Object.assign({}, primary)),
            secondary && React.createElement(Button.Button, Object.assign({}, secondary))),
        tertiary && (React.createElement("div", { className: styles$1.leftAction },
            React.createElement(Button.Button, Object.assign({}, tertiary))))))));
}

function useModal({ open, activatorRef: refProp, onRequestClose, }) {
    const nodeId = floatingUi_react.useFloatingNodeId();
    const defaultActivatorRef = React.useRef(null);
    const activatorRef = refProp !== null && refProp !== void 0 ? refProp : defaultActivatorRef;
    const { refs: floatingRefs, context: floatingContext } = floatingUi_react.useFloating({
        elements: { reference: activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current },
        nodeId,
        onOpenChange: (newOpen) => {
            if (!newOpen) {
                onRequestClose === null || onRequestClose === void 0 ? void 0 : onRequestClose();
            }
        },
        open: open,
    });
    const click = floatingUi_react.useClick(floatingContext);
    const dismiss = floatingUi_react.useDismiss(floatingContext, {
        outsidePressEvent: "click",
        escapeKey: true,
        bubbles: false,
    });
    const role = floatingUi_react.useRole(floatingContext);
    const { getFloatingProps } = floatingUi_react.useInteractions([click, dismiss, role]);
    const parentId = floatingUi_react.useFloatingParentNodeId();
    return {
        floatingRefs,
        floatingContext,
        nodeId,
        activatorRef,
        parentId,
        getFloatingProps,
    };
}

const ModalContext = React.createContext({
    open: false,
    onRequestClose: noop.noop,
    activatorRef: { current: null },
    floatingRefs: null,
    floatingContext: {},
    size: undefined,
    floatingNodeId: undefined,
    dismissible: true,
    getFloatingProps: identity.identity,
});
function ModalProvider({ children, open = false, size, onRequestClose = noop.noop, activatorRef: refProp, dismissible = true, modalLabelledBy = "ATL-Modal-Header", }) {
    const { floatingRefs, floatingContext, nodeId, activatorRef, parentId, getFloatingProps, } = useModal({
        open,
        activatorRef: refProp,
        onRequestClose,
    });
    const content = (React.createElement(ModalContext.Provider, { value: {
            onRequestClose,
            activatorRef,
            floatingRefs,
            floatingContext,
            size,
            open,
            floatingNodeId: nodeId,
            dismissible,
            modalLabelledBy,
            getFloatingProps,
        } }, children));
    if (parentId) {
        return content;
    }
    return React.createElement(floatingUi_react.FloatingTree, null, content);
}
function useModalContext() {
    return React.useContext(ModalContext);
}

var styles = {"overlay":"cRhQeXmZobs-","overlayBackground":"PO6ZUDxQoFE-","modal":"OiqCKNmbHZ0-","header":"GDWGHwmjgAc-","closeButton":"KJlGo4z-E6Q-","actionBar":"ZGrhWCAymCw-","leftAction":"hOiEWds2Vq8-","rightAction":"K31NzxPZP9s-","spinning":"SKeimJFlB-g-"};

function useModalStyles(size) {
    return {
        modal: classnames(styles.modal, size && sizes[size]),
        overlay: styles.overlay,
        header: styles.header,
        dismissButton: styles.closeButton,
        actionBar: styles.actionBar,
        leftAction: styles.leftAction,
        rightAction: styles.rightAction,
        overlayBackground: styles.overlayBackground,
    };
}

function ModalHeader({ title, children }) {
    const { header, dismissButton } = useModalStyles();
    const { dismissible, onRequestClose, modalLabelledBy } = useModalContext();
    if (children) {
        return React.createElement(React.Fragment, null, children);
    }
    return (React.createElement("div", { className: header, "data-testid": "ATL-Modal-Header", id: modalLabelledBy },
        React.createElement(Heading.Heading, { level: 2 }, title),
        dismissible && (React.createElement("div", { className: dismissButton },
            React.createElement(ButtonDismiss.ButtonDismiss, { onClick: onRequestClose, ariaLabel: "Close modal" })))));
}
function ModalActions({ primary, secondary, tertiary, }) {
    const { actionBar, rightAction, leftAction } = useModalStyles();
    const shouldShow = primary != undefined || secondary != undefined || tertiary != undefined;
    return (React.createElement(React.Fragment, null, shouldShow && (React.createElement("div", { className: actionBar, "data-testid": "ATL-Modal-Actions" },
        React.createElement("div", { className: rightAction },
            primary && React.createElement(Button.Button, Object.assign({}, primary)),
            secondary && (React.createElement(Button.Button, Object.assign({ type: "primary", variation: "subtle" }, secondary)))),
        tertiary && (React.createElement("div", { className: leftAction },
            React.createElement(Button.Button, Object.assign({ type: "secondary", variation: "destructive" }, tertiary))))))));
}
function ModalActivator({ children }) {
    const { activatorRef } = useModalContext();
    return (React.createElement("span", { ref: activatorRef, style: { display: "contents" } }, children));
}
/**
 * Background overlay for the modal. Used in the ModalContent.
 */
function ModalOverlay() {
    const { onRequestClose } = useModalContext();
    const { overlayBackground } = useModalStyles();
    return (React.createElement(framerMotion.motion.div, { onClick: onRequestClose, className: overlayBackground, initial: { opacity: 0 }, animate: { opacity: 0.8 }, exit: { opacity: 0 }, transition: { duration: 0.2 } }));
}
function ModalContent({ children }) {
    const { open, floatingContext, activatorRef, floatingRefs, size, floatingNodeId, modalLabelledBy, getFloatingProps, } = useModalContext();
    const { modal, overlay } = useModalStyles(size);
    return (React.createElement(framerMotion.AnimatePresence, null, open && (React.createElement(floatingUi_react.FloatingNode, { id: floatingNodeId },
        React.createElement(floatingUi_react.FloatingPortal, null,
            React.createElement(AtlantisPortalContent.AtlantisPortalContent, null,
                React.createElement(floatingUi_react.FloatingOverlay, { className: overlay },
                    React.createElement(floatingUi_react.FloatingFocusManager, { context: floatingContext, returnFocus: (activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current) ? activatorRef : true, initialFocus: floatingRefs === null || floatingRefs === void 0 ? void 0 : floatingRefs.floating },
                        React.createElement("div", Object.assign({ ref: floatingRefs === null || floatingRefs === void 0 ? void 0 : floatingRefs.setFloating, role: "dialog", tabIndex: 0, "aria-labelledby": modalLabelledBy }, getFloatingProps()),
                            React.createElement(ModalOverlay, null),
                            React.createElement(framerMotion.motion.div, { "data-floating-ui-focusable": true, className: modal, initial: { scale: 0.9, opacity: 0 }, animate: { scale: 1, opacity: 1 }, exit: { scale: 0.9, opacity: 0 }, transition: {
                                    duration: 0.2,
                                    ease: "easeInOut",
                                } }, children))))))))));
}

function Modal(props) {
    return React.createElement(ModalLegacy, Object.assign({}, props));
}
Modal.Header = ModalHeader;
Modal.Actions = ModalActions;
Modal.Activator = ModalActivator;
Modal.Provider = ModalProvider;
Modal.Content = ModalContent;

exports.Modal = Modal;
exports.useModalContext = useModalContext;
exports.useModalStyles = useModalStyles;
