import React__default, { useRef, createContext, useContext } from 'react';
import ReactDOM__default from 'react-dom';
import classnames from 'classnames';
import { AnimatePresence, motion } from 'framer-motion';
import { u as useRefocusOnActivator_2 } from '../useRefocusOnActivator-es.js';
import { u as useOnKeyDown_2 } from '../useOnKeyDown-es.js';
import { u as useFocusTrap_2 } from '../useFocusTrap-es.js';
import { H as Heading } from '../Heading-es.js';
import { B as Button } from '../Button-es.js';
import { B as ButtonDismiss } from '../ButtonDismiss-es.js';
import { n as noop } from '../noop-es.js';
import { a as useFloatingNodeId, b as useFloating, i as useClick, e as useDismiss, j as useRole, f as useInteractions, u as useFloatingParentNodeId, F as FloatingTree, g as FloatingNode, h as FloatingPortal, k as FloatingOverlay, l as FloatingFocusManager } from '../floating-ui.react-es.js';
import { b as identity } from '../identity-es.js';
import { A as AtlantisPortalContent } from '../AtlantisPortalContent-es.js';
import '../Typography-es.js';
import 'react-router-dom';
import '../tslib.es6-es.js';
import '../Icon-es.js';
import '@jobber/design';
import '../_commonjsHelpers-es.js';
import '../isTypedArray-es.js';
import '../isObjectLike-es.js';
import '../AtlantisThemeContext-es.js';
import '../_baseAssignValue-es.js';
import '../_baseFor-es.js';
import '../keysIn-es.js';
import '../_isIterateeCall-es.js';
import '../_setToString-es.js';

var styles$1 = {"container":"y3M-9xoEnk0-","overlay":"zkyJp1mib-U-","modal":"gMPgiggaud8-","header":"_5sBzUnyOqD0-","closeButton":"_4gw63G7IYG0-","actionBar":"cwVJrrJkNDg-","leftAction":"MkD4pNUKeAA-","rightAction":"C-yC8JKpQLg-","spinning":"_7hYqr6OrfHs-"};

var sizes = {"small":"BSZvIAUzFEU-","large":"-ydIALYVvGg-","spinning":"_10FfgKITqY0-"};

function ModalLegacy({ open = false, title, size, dismissible = true, children, primaryAction, secondaryAction, tertiaryAction, onRequestClose, }) {
    const modalClassName = classnames(styles$1.modal, size && sizes[size]);
    useRefocusOnActivator_2(open);
    const modalRef = useFocusTrap_2(open);
    useOnKeyDown_2(handleRequestClose, "Escape");
    const template = (React__default.createElement(AnimatePresence, null, open && (React__default.createElement("div", { ref: modalRef, role: "dialog", className: styles$1.container, tabIndex: 0 },
        React__default.createElement(motion.div, { key: styles$1.overlay, className: styles$1.overlay, onClick: onRequestClose, initial: { opacity: 0 }, animate: { opacity: 0.8 }, exit: { opacity: 0 }, transition: { duration: 0.2 } }),
        React__default.createElement(motion.div, { key: styles$1.modal, className: modalClassName, initial: { scale: 0.9, opacity: 0 }, animate: { scale: 1, opacity: 1 }, exit: { scale: 0.9, opacity: 0 }, transition: {
                duration: 0.2,
                ease: "easeInOut",
            } },
            title != undefined && (React__default.createElement(Header, { title: title, dismissible: dismissible, onRequestClose: onRequestClose })),
            children,
            React__default.createElement(Actions, { primary: primaryAction, secondary: secondaryAction, tertiary: tertiaryAction }))))));
    return (globalThis === null || globalThis === void 0 ? void 0 : globalThis.document)
        ? ReactDOM__default.createPortal(template, document.body)
        : template;
    function handleRequestClose() {
        if (open && onRequestClose) {
            onRequestClose();
        }
    }
}
function Header({ title, dismissible, onRequestClose }) {
    return (React__default.createElement("div", { className: styles$1.header, "data-testid": "modal-header" },
        React__default.createElement(Heading, { level: 2 }, title),
        dismissible && (React__default.createElement("div", { className: styles$1.closeButton },
            React__default.createElement(ButtonDismiss, { onClick: onRequestClose, ariaLabel: "Close modal" })))));
}
function Actions({ primary, secondary, tertiary }) {
    const shouldShow = primary != undefined || secondary != undefined || tertiary != undefined;
    if (secondary != undefined) {
        secondary = Object.assign({ type: "primary", variation: "subtle" }, secondary);
    }
    if (tertiary != undefined) {
        tertiary = Object.assign({ type: "secondary", variation: "destructive" }, tertiary);
    }
    return (React__default.createElement(React__default.Fragment, null, shouldShow && (React__default.createElement("div", { className: styles$1.actionBar },
        React__default.createElement("div", { className: styles$1.rightAction },
            primary && React__default.createElement(Button, Object.assign({}, primary)),
            secondary && React__default.createElement(Button, Object.assign({}, secondary))),
        tertiary && (React__default.createElement("div", { className: styles$1.leftAction },
            React__default.createElement(Button, Object.assign({}, tertiary))))))));
}

function useModal({ open, activatorRef: refProp, onRequestClose, }) {
    const nodeId = useFloatingNodeId();
    const defaultActivatorRef = useRef(null);
    const activatorRef = refProp !== null && refProp !== void 0 ? refProp : defaultActivatorRef;
    const { refs: floatingRefs, context: floatingContext } = useFloating({
        elements: { reference: activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current },
        nodeId,
        onOpenChange: (newOpen) => {
            if (!newOpen) {
                onRequestClose === null || onRequestClose === void 0 ? void 0 : onRequestClose();
            }
        },
        open: open,
    });
    const click = useClick(floatingContext);
    const dismiss = useDismiss(floatingContext, {
        outsidePressEvent: "click",
        escapeKey: true,
        bubbles: false,
    });
    const role = useRole(floatingContext);
    const { getFloatingProps } = useInteractions([click, dismiss, role]);
    const parentId = useFloatingParentNodeId();
    return {
        floatingRefs,
        floatingContext,
        nodeId,
        activatorRef,
        parentId,
        getFloatingProps,
    };
}

const ModalContext = createContext({
    open: false,
    onRequestClose: noop,
    activatorRef: { current: null },
    floatingRefs: null,
    floatingContext: {},
    size: undefined,
    floatingNodeId: undefined,
    dismissible: true,
    getFloatingProps: identity,
});
function ModalProvider({ children, open = false, size, onRequestClose = noop, activatorRef: refProp, dismissible = true, modalLabelledBy = "ATL-Modal-Header", }) {
    const { floatingRefs, floatingContext, nodeId, activatorRef, parentId, getFloatingProps, } = useModal({
        open,
        activatorRef: refProp,
        onRequestClose,
    });
    const content = (React__default.createElement(ModalContext.Provider, { value: {
            onRequestClose,
            activatorRef,
            floatingRefs,
            floatingContext,
            size,
            open,
            floatingNodeId: nodeId,
            dismissible,
            modalLabelledBy,
            getFloatingProps,
        } }, children));
    if (parentId) {
        return content;
    }
    return React__default.createElement(FloatingTree, null, content);
}
function useModalContext() {
    return useContext(ModalContext);
}

var styles = {"overlay":"cRhQeXmZobs-","overlayBackground":"PO6ZUDxQoFE-","modal":"OiqCKNmbHZ0-","header":"GDWGHwmjgAc-","closeButton":"KJlGo4z-E6Q-","actionBar":"ZGrhWCAymCw-","leftAction":"hOiEWds2Vq8-","rightAction":"K31NzxPZP9s-","spinning":"SKeimJFlB-g-"};

function useModalStyles(size) {
    return {
        modal: classnames(styles.modal, size && sizes[size]),
        overlay: styles.overlay,
        header: styles.header,
        dismissButton: styles.closeButton,
        actionBar: styles.actionBar,
        leftAction: styles.leftAction,
        rightAction: styles.rightAction,
        overlayBackground: styles.overlayBackground,
    };
}

function ModalHeader({ title, children }) {
    const { header, dismissButton } = useModalStyles();
    const { dismissible, onRequestClose, modalLabelledBy } = useModalContext();
    if (children) {
        return React__default.createElement(React__default.Fragment, null, children);
    }
    return (React__default.createElement("div", { className: header, "data-testid": "ATL-Modal-Header", id: modalLabelledBy },
        React__default.createElement(Heading, { level: 2 }, title),
        dismissible && (React__default.createElement("div", { className: dismissButton },
            React__default.createElement(ButtonDismiss, { onClick: onRequestClose, ariaLabel: "Close modal" })))));
}
function ModalActions({ primary, secondary, tertiary, }) {
    const { actionBar, rightAction, leftAction } = useModalStyles();
    const shouldShow = primary != undefined || secondary != undefined || tertiary != undefined;
    return (React__default.createElement(React__default.Fragment, null, shouldShow && (React__default.createElement("div", { className: actionBar, "data-testid": "ATL-Modal-Actions" },
        React__default.createElement("div", { className: rightAction },
            primary && React__default.createElement(Button, Object.assign({}, primary)),
            secondary && (React__default.createElement(Button, Object.assign({ type: "primary", variation: "subtle" }, secondary)))),
        tertiary && (React__default.createElement("div", { className: leftAction },
            React__default.createElement(Button, Object.assign({ type: "secondary", variation: "destructive" }, tertiary))))))));
}
function ModalActivator({ children }) {
    const { activatorRef } = useModalContext();
    return (React__default.createElement("span", { ref: activatorRef, style: { display: "contents" } }, children));
}
/**
 * Background overlay for the modal. Used in the ModalContent.
 */
function ModalOverlay() {
    const { onRequestClose } = useModalContext();
    const { overlayBackground } = useModalStyles();
    return (React__default.createElement(motion.div, { onClick: onRequestClose, className: overlayBackground, initial: { opacity: 0 }, animate: { opacity: 0.8 }, exit: { opacity: 0 }, transition: { duration: 0.2 } }));
}
function ModalContent({ children }) {
    const { open, floatingContext, activatorRef, floatingRefs, size, floatingNodeId, modalLabelledBy, getFloatingProps, } = useModalContext();
    const { modal, overlay } = useModalStyles(size);
    return (React__default.createElement(AnimatePresence, null, open && (React__default.createElement(FloatingNode, { id: floatingNodeId },
        React__default.createElement(FloatingPortal, null,
            React__default.createElement(AtlantisPortalContent, null,
                React__default.createElement(FloatingOverlay, { className: overlay },
                    React__default.createElement(FloatingFocusManager, { context: floatingContext, returnFocus: (activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current) ? activatorRef : true, initialFocus: floatingRefs === null || floatingRefs === void 0 ? void 0 : floatingRefs.floating },
                        React__default.createElement("div", Object.assign({ ref: floatingRefs === null || floatingRefs === void 0 ? void 0 : floatingRefs.setFloating, role: "dialog", tabIndex: 0, "aria-labelledby": modalLabelledBy }, getFloatingProps()),
                            React__default.createElement(ModalOverlay, null),
                            React__default.createElement(motion.div, { "data-floating-ui-focusable": true, className: modal, initial: { scale: 0.9, opacity: 0 }, animate: { scale: 1, opacity: 1 }, exit: { scale: 0.9, opacity: 0 }, transition: {
                                    duration: 0.2,
                                    ease: "easeInOut",
                                } }, children))))))))));
}

function Modal(props) {
    return React__default.createElement(ModalLegacy, Object.assign({}, props));
}
Modal.Header = ModalHeader;
Modal.Actions = ModalActions;
Modal.Activator = ModalActivator;
Modal.Provider = ModalProvider;
Modal.Content = ModalContent;

export { Modal, useModalContext, useModalStyles };
