import React, { ReactNode } from "react";
import { XOR } from "ts-xor";
import { ButtonProps } from "../Button";
import { SectionProps } from "../Menu";
export type ButtonActionProps = ButtonProps & {
    ref?: React.RefObject<HTMLDivElement>;
};
interface PageFoundationProps {
    readonly children: ReactNode | ReactNode[];
    /**
     * Title of the page.
     */
    readonly title: string;
    /**
     * TitleMetaData component to be displayed
     * next to the title.
     */
    readonly titleMetaData?: ReactNode;
    /**
     * Subtitle of the page.
     */
    readonly subtitle?: string;
    /**
     * Determines the width of the page.
     *
     * Fill makes the width grow to 100%.
     *
     * Standard caps out at 1280px.
     *
     * Narrow caps out at 1024px.
     *
     * @default standard
     */
    readonly width?: "fill" | "standard" | "narrow";
    /**
     * Page title primary action button settings.
     */
    readonly primaryAction?: ButtonActionProps;
    /**
     * Page title secondary action button settings.
     */
    readonly secondaryAction?: ButtonActionProps;
    /**
     * Page title Action menu.
     */
    readonly moreActionsMenu?: SectionProps[];
}
interface PageWithIntroProps extends PageFoundationProps {
    /**
     * Content of the page. This supports basic markdown node types
     * such as `_italic_`, `**bold**`, and `[link name](url)`.
     */
    readonly intro: string;
    /**
     * Causes any markdown links in the `intro` prop to open in a new
     * tab, i.e. with `target="_blank"`.
     *
     * Can only be used if `intro` prop is also specified.
     *
     * Defaults to `false`.
     */
    readonly externalIntroLinks?: boolean;
}
export type PageProps = XOR<PageFoundationProps, PageWithIntroProps>;
export declare function Page({ title, titleMetaData, intro, externalIntroLinks, subtitle, children, width, primaryAction, secondaryAction, moreActionsMenu, }: PageProps): React.JSX.Element;
export declare const getActionProps: (actionProps: ButtonActionProps) => ButtonProps;
export {};
