'use strict';

var tslib_es6 = require('./tslib.es6-cjs.js');
var React = require('react');
var classnames = require('classnames');
var ReactDOM = require('react-dom');
var reactPopper = require('react-popper');
var useRefocusOnActivator = require('./useRefocusOnActivator-cjs.js');
var AtlantisPortalContent = require('./AtlantisPortalContent-cjs.js');
var ButtonDismiss = require('./ButtonDismiss-cjs.js');

const usePopover = ({ preferredPlacement, attachTo, open, }) => {
    const [popperElement, setPopperElement] = React.useState();
    const [arrowElement, setArrowElement] = React.useState();
    const modifiers = React.useMemo(() => {
        return [
            {
                name: "arrow",
                options: { element: arrowElement, padding: 10 },
            },
            {
                name: "offset",
                options: {
                    offset: [0, 10],
                },
            },
            {
                name: "flip",
                options: {
                    fallbackPlacements: ["auto"],
                },
            },
        ];
    }, [arrowElement]);
    const { styles: popperStyles, attributes } = reactPopper.usePopper(isHTMLElement(attachTo) ? attachTo : attachTo.current, popperElement, {
        modifiers,
        placement: preferredPlacement,
    });
    useRefocusOnActivator.useRefocusOnActivator_2(open);
    return { setPopperElement, setArrowElement, popperStyles, attributes };
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isHTMLElement(el) {
    return (globalThis === null || globalThis === void 0 ? void 0 : globalThis.document) && el instanceof Element;
}

var styles = {"popover":"rY8OtuArIi0-","header":"UI1AohefbSo-","dismissButton":"HyA0TM5soDM-","arrow":"uClo-5-xhAc-","spinning":"VA0ROLmpLPs-"};

const usePopoverStyles = () => {
    return {
        container: styles.popover,
        dismissButton: styles.dismissButton,
        arrow: styles.arrow,
    };
};

const PopoverContext = React.createContext({
    popperStyles: {},
    setArrowElement: () => {
        // noop
    },
});
function usePopoverContext() {
    return React.useContext(PopoverContext);
}
function PopoverProvider({ children, preferredPlacement, attachTo, open, UNSAFE_className, UNSAFE_style, }) {
    const { setPopperElement, setArrowElement, popperStyles, attributes } = usePopover({
        preferredPlacement,
        attachTo,
        open,
    });
    if (!open)
        return null;
    return (React.createElement(PopoverContext.Provider, { value: {
            setArrowElement,
            popperStyles,
        } },
        React.createElement(PopoverWrapper, { attributes: attributes, UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style, setPopperElement: setPopperElement }, children)));
}
function PopoverWrapper({ children, attributes, setPopperElement, UNSAFE_className, UNSAFE_style, }) {
    const popoverStyles = usePopoverStyles();
    const { popperStyles } = usePopoverContext();
    const classes = classnames(popoverStyles.container, UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.container);
    const content = (React.createElement(AtlantisPortalContent.AtlantisPortalContent, null,
        React.createElement("div", Object.assign({ role: "dialog", "data-elevation": "elevated", ref: setPopperElement, style: Object.assign(Object.assign({}, popperStyles.popper), UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.container), className: classes }, attributes.popper, { "data-testid": "ATL-Popover-Container" }), children)));
    return ReactDOM.createPortal(content, document.body);
}

function Popover({ onRequestClose, children, attachTo, open, preferredPlacement = "auto", UNSAFE_className, UNSAFE_style, }) {
    return (React.createElement(Popover.Provider, { attachTo: attachTo, open: open, preferredPlacement: preferredPlacement, UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style },
        React.createElement(Popover.DismissButton, { UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style, onClick: onRequestClose }),
        children,
        React.createElement(Popover.Arrow, { UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style })));
}
Popover.Provider = PopoverProvider;
Popover.Arrow = function PopoverArrow({ UNSAFE_className, UNSAFE_style, }) {
    const { setArrowElement, popperStyles } = usePopoverContext();
    const popoverStyles = usePopoverStyles();
    const classes = classnames(popoverStyles.arrow, UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.arrow);
    return (React.createElement("div", { ref: setArrowElement, className: classes, style: Object.assign(Object.assign({}, popperStyles.arrow), UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.arrow), "data-testid": "ATL-Popover-Arrow" }));
};
Popover.DismissButton = function PopoverDismissButton(props) {
    var _a;
    const { UNSAFE_className, UNSAFE_style, children } = props, dismissButtonProps = tslib_es6.__rest(props, ["UNSAFE_className", "UNSAFE_style", "children"]);
    const popoverStyles = usePopoverStyles();
    const classes = classnames(popoverStyles.dismissButton, UNSAFE_className === null || UNSAFE_className === void 0 ? void 0 : UNSAFE_className.dismissButtonContainer);
    return (React.createElement("div", { className: classes, style: (_a = UNSAFE_style === null || UNSAFE_style === void 0 ? void 0 : UNSAFE_style.dismissButtonContainer) !== null && _a !== void 0 ? _a : {}, "data-testid": "ATL-Popover-Dismiss-Button-Container" }, children !== null && children !== void 0 ? children : (React.createElement(ButtonDismiss.ButtonDismiss, Object.assign({ ariaLabel: "Close dialog" }, dismissButtonProps)))));
};

exports.Popover = Popover;
exports.usePopoverContext = usePopoverContext;
exports.usePopoverStyles = usePopoverStyles;
