'use strict';

var React = require('react');
var omit = require('../omit-cjs.js');
var FormField = require('../FormField-cjs.js');
require('classnames');
require('../tslib.es6-cjs.js');
require('react-hook-form');
require('framer-motion');
require('@jobber/design');
require('../Button-cjs.js');
require('../_commonjsHelpers-cjs.js');
require('../_baseGet-cjs.js');
require('../isTypedArray-cjs.js');
require('../isObjectLike-cjs.js');
require('../identity-cjs.js');
require('../_getTag-cjs.js');
require('../isSymbol-cjs.js');
require('../keysIn-cjs.js');
require('../_baseAssignValue-cjs.js');
require('../_baseFlatten-cjs.js');
require('../_setToString-cjs.js');
require('../Icon-cjs.js');
require('../Text-cjs.js');
require('../Typography-cjs.js');
require('../useFormFieldFocus-cjs.js');
require('../InputValidation-cjs.js');
require('../Spinner-cjs.js');
require('react-router-dom');

function Select$1(props) {
    const formFieldProps = omit.omit(Object.assign({}, props), ["version"]);
    return React.createElement(FormField.FormField, Object.assign({ type: "select" }, formFieldProps));
}

/**
 * Hook with actions on the Select component.
 */
function useSelectActions({ onChange, onBlur, onFocus, }) {
    function handleChange(event) {
        const newValue = event.currentTarget.value;
        onChange === null || onChange === void 0 ? void 0 : onChange(newValue, event);
    }
    function handleBlur() {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur();
    }
    function handleFocus() {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus();
    }
    return {
        handleChange,
        handleBlur,
        handleFocus,
    };
}

/**
 * Hook for managing the props of a Select component.
 * Extracted from FormField's useAtlantisFormField.
 */
function useSelectFormField({ id, name, disabled, autofocus, description, inline, value, handleChange, handleBlur, handleFocus, }) {
    const descriptionIdentifier = `descriptionUUID--${id}`;
    const fieldProps = Object.assign({ id,
        name,
        disabled, autoFocus: autofocus, onChange: handleChange, onBlur: handleBlur, onFocus: handleFocus, value }, (description &&
        !inline && { "aria-describedby": descriptionIdentifier }));
    return { fieldProps, descriptionIdentifier };
}

function SelectRebuilt(props) {
    var _a, _b;
    const selectRef = (_a = props.inputRef) !== null && _a !== void 0 ? _a : React.useRef(null);
    const wrapperRef = React.useRef(null);
    const { inputStyle } = FormField.useFormFieldWrapperStyles(Object.assign({}, omit.omit(props, ["version"])));
    const id = useSelectId(props);
    const { name } = FormField.useAtlantisFormFieldName({
        nameProp: props.name,
        id: id,
    });
    const { handleChange, handleBlur, handleFocus } = useSelectActions({
        onChange: props.onChange,
        onBlur: props.onBlur,
        onFocus: props.onFocus,
    });
    const inputProps = omit.omit(props, [
        "onChange",
        "onBlur",
        "onFocus",
        "size",
        "placeholder",
        "version",
    ]);
    const { fieldProps, descriptionIdentifier } = useSelectFormField(Object.assign(Object.assign({}, inputProps), { id,
        name,
        handleChange,
        handleBlur,
        handleFocus }));
    return (React.createElement(FormField.FormFieldWrapper, { disabled: props.disabled, size: props.size, align: props.align, inline: props.inline, autofocus: props.autofocus, name: name, wrapperRef: wrapperRef, error: (_b = props.error) !== null && _b !== void 0 ? _b : "", invalid: props.invalid, identifier: id, descriptionIdentifier: descriptionIdentifier, description: props.description, type: "select", placeholder: props.placeholder, value: props.value, prefix: props.prefix, suffix: props.suffix, clearable: "never", maxLength: props.maxLength },
        React.createElement(React.Fragment, null,
            React.createElement("select", Object.assign({}, fieldProps, { ref: selectRef, className: inputStyle }), props.children),
            React.createElement(FormField.FormFieldPostFix, { variation: "select" }))));
}
function useSelectId(props) {
    const generatedId = React.useId();
    return props.id || generatedId;
}

function SelectOption({ children, disabled, value }) {
    return (React.createElement("option", { disabled: disabled, value: value }, children));
}

function isNewSelectProps(props) {
    return props.version === 2;
}
function Select(props) {
    if (isNewSelectProps(props)) {
        return React.createElement(SelectRebuilt, Object.assign({}, props));
    }
    else {
        return React.createElement(Select$1, Object.assign({}, props));
    }
}

exports.Option = SelectOption;
exports.Select = Select;
