import React__default, { useRef, useId } from 'react';
import { o as omit } from '../omit-es.js';
import { k as FormField, j as useFormFieldWrapperStyles, b as useAtlantisFormFieldName, f as FormFieldWrapper, l as FormFieldPostFix } from '../FormField-es.js';
import 'classnames';
import '../tslib.es6-es.js';
import 'react-hook-form';
import 'framer-motion';
import '@jobber/design';
import '../Button-es.js';
import '../_commonjsHelpers-es.js';
import '../_baseGet-es.js';
import '../isTypedArray-es.js';
import '../isObjectLike-es.js';
import '../identity-es.js';
import '../_getTag-es.js';
import '../isSymbol-es.js';
import '../keysIn-es.js';
import '../_baseAssignValue-es.js';
import '../_baseFlatten-es.js';
import '../_setToString-es.js';
import '../Icon-es.js';
import '../Text-es.js';
import '../Typography-es.js';
import '../useFormFieldFocus-es.js';
import '../InputValidation-es.js';
import '../Spinner-es.js';
import 'react-router-dom';

function Select$1(props) {
    const formFieldProps = omit(Object.assign({}, props), ["version"]);
    return React__default.createElement(FormField, Object.assign({ type: "select" }, formFieldProps));
}

/**
 * Hook with actions on the Select component.
 */
function useSelectActions({ onChange, onBlur, onFocus, }) {
    function handleChange(event) {
        const newValue = event.currentTarget.value;
        onChange === null || onChange === void 0 ? void 0 : onChange(newValue, event);
    }
    function handleBlur() {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur();
    }
    function handleFocus() {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus();
    }
    return {
        handleChange,
        handleBlur,
        handleFocus,
    };
}

/**
 * Hook for managing the props of a Select component.
 * Extracted from FormField's useAtlantisFormField.
 */
function useSelectFormField({ id, name, disabled, autofocus, description, inline, value, handleChange, handleBlur, handleFocus, }) {
    const descriptionIdentifier = `descriptionUUID--${id}`;
    const fieldProps = Object.assign({ id,
        name,
        disabled, autoFocus: autofocus, onChange: handleChange, onBlur: handleBlur, onFocus: handleFocus, value }, (description &&
        !inline && { "aria-describedby": descriptionIdentifier }));
    return { fieldProps, descriptionIdentifier };
}

function SelectRebuilt(props) {
    var _a, _b;
    const selectRef = (_a = props.inputRef) !== null && _a !== void 0 ? _a : useRef(null);
    const wrapperRef = useRef(null);
    const { inputStyle } = useFormFieldWrapperStyles(Object.assign({}, omit(props, ["version"])));
    const id = useSelectId(props);
    const { name } = useAtlantisFormFieldName({
        nameProp: props.name,
        id: id,
    });
    const { handleChange, handleBlur, handleFocus } = useSelectActions({
        onChange: props.onChange,
        onBlur: props.onBlur,
        onFocus: props.onFocus,
    });
    const inputProps = omit(props, [
        "onChange",
        "onBlur",
        "onFocus",
        "size",
        "placeholder",
        "version",
    ]);
    const { fieldProps, descriptionIdentifier } = useSelectFormField(Object.assign(Object.assign({}, inputProps), { id,
        name,
        handleChange,
        handleBlur,
        handleFocus }));
    return (React__default.createElement(FormFieldWrapper, { disabled: props.disabled, size: props.size, align: props.align, inline: props.inline, autofocus: props.autofocus, name: name, wrapperRef: wrapperRef, error: (_b = props.error) !== null && _b !== void 0 ? _b : "", invalid: props.invalid, identifier: id, descriptionIdentifier: descriptionIdentifier, description: props.description, type: "select", placeholder: props.placeholder, value: props.value, prefix: props.prefix, suffix: props.suffix, clearable: "never", maxLength: props.maxLength },
        React__default.createElement(React__default.Fragment, null,
            React__default.createElement("select", Object.assign({}, fieldProps, { ref: selectRef, className: inputStyle }), props.children),
            React__default.createElement(FormFieldPostFix, { variation: "select" }))));
}
function useSelectId(props) {
    const generatedId = useId();
    return props.id || generatedId;
}

function SelectOption({ children, disabled, value }) {
    return (React__default.createElement("option", { disabled: disabled, value: value }, children));
}

function isNewSelectProps(props) {
    return props.version === 2;
}
function Select(props) {
    if (isNewSelectProps(props)) {
        return React__default.createElement(SelectRebuilt, Object.assign({}, props));
    }
    else {
        return React__default.createElement(Select$1, Object.assign({}, props));
    }
}

export { SelectOption as Option, Select };
