import React from "react";
import type { CSSProperties, PropsWithChildren } from "react";
import { SideDrawerActions } from "./SideDrawerActions";
import { SideDrawerTitle } from "./SideDrawerTitle";
import { SideDrawerToolbar } from "./SideDrawerToolbar";
import { SideDrawerBackButton } from "./SideDrawerBackButton";
import { SideDrawerFooter } from "./SideDrawerFooter";
interface SideDrawerProps extends PropsWithChildren {
    /**
     * Whether or not the drawer is open.
     */
    readonly open: boolean;
    /**
     * Callback function to close the drawer.
     */
    readonly onRequestClose: () => void;
    /**
     * Change the appearance of the drawer.
     */
    readonly variation?: "base" | "subtle";
    /**
     * Change the scrolling direction of the drawer. Useful for chat-like interfaces.
     */
    readonly scrollDirection?: "normal" | "reverse";
    /**
     * Changes whether the SideDrawer is positioned to the side of the viewport or inline with the content.
     * @default false
     */
    readonly inline?: boolean;
    /**
     * **Use at your own risk:** Custom class names for specific elements. This should only be used as a
     * **last resort**. Using this may result in unexpected side effects.
     * More information in the [Customizing components Guide](https://atlantis.getjobber.com/guides/customizing-components).
     */
    readonly UNSAFE_className?: {
        container?: string;
    };
    /**
     * **Use at your own risk:** Custom style for specific elements. This should only be used as a
     * **last resort**. Using this may result in unexpected side effects.
     * More information in the [Customizing components Guide](https://atlantis.getjobber.com/guides/customizing-components).
     */
    readonly UNSAFE_style?: {
        container?: CSSProperties;
    };
}
export declare function SideDrawer({ children, onRequestClose, open, variation, scrollDirection, inline, UNSAFE_className, UNSAFE_style, }: SideDrawerProps): React.JSX.Element | null;
export declare namespace SideDrawer {
    var Title: typeof SideDrawerTitle;
    var Toolbar: typeof SideDrawerToolbar;
    var Actions: typeof SideDrawerActions;
    var BackButton: typeof SideDrawerBackButton;
    var Footer: typeof SideDrawerFooter;
}
export {};
