'use strict';

var React = require('react');

var useFocusTrap$1 = {};

Object.defineProperty(useFocusTrap$1, "__esModule", { value: true });
var useFocusTrap_2 = useFocusTrap$1.useFocusTrap = useFocusTrap;
const react_1 = React;
/**
 * Traps the focus within the children of the ref element.
 *
 * @param active - Turns the focus trapping on or off. Also adds aria-hidden on the
 * body but not the dialog.
 *
 * @returns ref
 */
function useFocusTrap(active) {
    // There's an ongoing issue with useRef return type clashing with an element's
    // ref prop type. TLDR: Use null because useRef doesn't expect undefined.
    // https://github.com/DefinitelyTyped/DefinitelyTyped/issues/35572
    const ref = (0, react_1.useRef)(null);
    function handleKeyDown(event) {
        if (!(active && ref.current) || event.key !== "Tab") {
            return;
        }
        const { firstElement, lastElement } = getElements(ref.current);
        if (event.shiftKey) {
            if (document.activeElement === firstElement) {
                lastElement.focus();
                event.preventDefault();
            }
        }
        else {
            if (document.activeElement === lastElement) {
                firstElement.focus();
                event.preventDefault();
            }
        }
    }
    (0, react_1.useEffect)(() => {
        if (active && ref.current) {
            const { firstElement } = getElements(ref.current);
            firstElement.focus();
            ref.current.addEventListener("keydown", handleKeyDown);
        }
        return () => {
            var _a;
            (_a = ref.current) === null || _a === void 0 ? void 0 : _a.removeEventListener("keydown", handleKeyDown);
        };
    }, [active]);
    return ref;
}
function getElements(ref) {
    const focusables = [
        "button",
        "[href]",
        "input",
        "select",
        "textarea",
        '[tabindex]:not([tabindex="-1"])',
    ];
    const elements = [
        ...ref.querySelectorAll(focusables.join(", ")),
    ];
    // If the ref is focusable, ensure it's the first element to be focused.
    if (ref.getAttribute("tabindex") === "0") {
        elements.unshift(ref);
    }
    const firstElement = elements[0];
    const lastElement = elements[elements.length - 1];
    return { firstElement, lastElement };
}

exports.useFocusTrap_2 = useFocusTrap_2;
