import { ChangeEvent, FocusEvent, KeyboardEvent } from "react";
export interface useInputTextFormFieldProps extends React.InputHTMLAttributes<HTMLInputElement | HTMLTextAreaElement> {
    /**
     * The html id for the field
     */
    readonly id: string;
    /**
     * The auto-generated name for the html input field if a nameProp is not provided
     */
    readonly name: string;
    /**
     * The error message for the field
     */
    readonly error?: string;
    /**
     * Adjusts the form field to go inline with a content. This also silences the
     * given `validations` prop. You'd have to used the `onValidate` prop to
     * capture the message and render it somewhere else using the
     * `InputValidation` component.
     */
    readonly inline?: boolean;
    /**
     * Further description of the input, can be used for a hint.
     */
    readonly description?: string;
    /**
     * Callback for when the field value changes
     */
    handleChange: (event: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
    /**
     * Callback for when the field loses focus
     */
    handleBlur: () => void;
    /**
     * Callback for when the field gains focus
     */
    handleFocus: (event: FocusEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
    /**
     * Callback for when keydown event is triggered on the field
     */
    handleKeyDown: (event: KeyboardEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
    readonly invalid?: boolean;
}
export interface UseInputTextFormFieldReturn {
    fieldProps: React.InputHTMLAttributes<HTMLInputElement | HTMLTextAreaElement>;
}
/**
 * Provides the props for the html fields rendered by the html input.
 *  DO not repeat this pattern. We are doing this as a proof of concept relating to the refactoring of Form inputs to see what can be removed.
 */
export declare function useInputTextFormField({ id, name, description, inline, handleChange, handleBlur, handleFocus, handleKeyDown, error, ...rest }: useInputTextFormFieldProps): {
    fieldProps: {
        "aria-invalid": boolean | undefined;
        autoFocus: boolean | undefined;
        invalid: string | undefined;
        onKeyDown: (event: KeyboardEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
        "aria-describedby"?: string | undefined;
        id: string;
        className: string;
        name: string;
        disabled: boolean | undefined;
        inputMode: "none" | "text" | "search" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
        onChange: (event: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
        onBlur: () => void;
        onFocus: (event: FocusEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
        accept?: string | undefined;
        alt?: string | undefined;
        autoComplete?: import("react").HTMLInputAutoCompleteAttribute | undefined;
        capture?: boolean | "user" | "environment" | undefined;
        checked?: boolean | undefined;
        enterKeyHint?: "enter" | "done" | "go" | "next" | "previous" | "search" | "send" | undefined;
        form?: string | undefined;
        formAction?: string | import("react").DO_NOT_USE_OR_YOU_WILL_BE_FIRED_EXPERIMENTAL_FORM_ACTIONS[keyof import("react").DO_NOT_USE_OR_YOU_WILL_BE_FIRED_EXPERIMENTAL_FORM_ACTIONS] | undefined;
        formEncType?: string | undefined;
        formMethod?: string | undefined;
        formNoValidate?: boolean | undefined;
        formTarget?: string | undefined;
        height?: number | string | undefined;
        list?: string | undefined;
        max?: number | string | undefined;
        maxLength?: number | undefined;
        min?: number | string | undefined;
        minLength?: number | undefined;
        multiple?: boolean | undefined;
        pattern?: string | undefined;
        placeholder?: string | undefined;
        readOnly?: boolean | undefined;
        required?: boolean | undefined;
        size?: number | undefined;
        src?: string | undefined;
        step?: number | string | undefined;
        type?: import("react").HTMLInputTypeAttribute | undefined;
        value?: string | readonly string[] | number | undefined;
        width?: number | string | undefined;
        defaultChecked?: boolean | undefined;
        defaultValue?: string | number | readonly string[] | undefined;
        suppressContentEditableWarning?: boolean | undefined;
        suppressHydrationWarning?: boolean | undefined;
        accessKey?: string | undefined;
        contentEditable?: (boolean | "false" | "true") | "inherit" | "plaintext-only" | undefined;
        contextMenu?: string | undefined;
        dir?: string | undefined;
        draggable?: (boolean | "false" | "true") | undefined;
        hidden?: boolean | undefined;
        lang?: string | undefined;
        nonce?: string | undefined;
        slot?: string | undefined;
        spellCheck?: (boolean | "false" | "true") | undefined;
        style?: import("react").CSSProperties | undefined;
        tabIndex?: number | undefined;
        title?: string | undefined;
        translate?: "yes" | "no" | undefined;
        radioGroup?: string | undefined;
        role?: import("react").AriaRole | undefined;
        about?: string | undefined;
        content?: string | undefined;
        datatype?: string | undefined;
        inlist?: any;
        prefix?: string | undefined;
        property?: string | undefined;
        rel?: string | undefined;
        resource?: string | undefined;
        rev?: string | undefined;
        typeof?: string | undefined;
        vocab?: string | undefined;
        autoCapitalize?: string | undefined;
        autoCorrect?: string | undefined;
        autoSave?: string | undefined;
        color?: string | undefined;
        itemProp?: string | undefined;
        itemScope?: boolean | undefined;
        itemType?: string | undefined;
        itemID?: string | undefined;
        itemRef?: string | undefined;
        results?: number | undefined;
        security?: string | undefined;
        unselectable?: "on" | "off" | undefined;
        is?: string | undefined;
        "aria-activedescendant"?: string | undefined;
        "aria-atomic"?: (boolean | "false" | "true") | undefined;
        "aria-autocomplete"?: "none" | "inline" | "list" | "both" | undefined;
        "aria-braillelabel"?: string | undefined;
        "aria-brailleroledescription"?: string | undefined;
        "aria-busy"?: (boolean | "false" | "true") | undefined;
        "aria-checked"?: boolean | "false" | "mixed" | "true" | undefined;
        "aria-colcount"?: number | undefined;
        "aria-colindex"?: number | undefined;
        "aria-colindextext"?: string | undefined;
        "aria-colspan"?: number | undefined;
        "aria-controls"?: string | undefined;
        "aria-current"?: boolean | "false" | "true" | "page" | "step" | "location" | "date" | "time" | undefined;
        "aria-description"?: string | undefined;
        "aria-details"?: string | undefined;
        "aria-disabled"?: (boolean | "false" | "true") | undefined;
        "aria-dropeffect"?: "none" | "copy" | "execute" | "link" | "move" | "popup" | undefined;
        "aria-errormessage"?: string | undefined;
        "aria-expanded"?: (boolean | "false" | "true") | undefined;
        "aria-flowto"?: string | undefined;
        "aria-grabbed"?: (boolean | "false" | "true") | undefined;
        "aria-haspopup"?: boolean | "false" | "true" | "menu" | "listbox" | "tree" | "grid" | "dialog" | undefined;
        "aria-hidden"?: (boolean | "false" | "true") | undefined;
        "aria-keyshortcuts"?: string | undefined;
        "aria-label"?: string | undefined;
        "aria-labelledby"?: string | undefined;
        "aria-level"?: number | undefined;
        "aria-live"?: "off" | "assertive" | "polite" | undefined;
        "aria-modal"?: (boolean | "false" | "true") | undefined;
        "aria-multiline"?: (boolean | "false" | "true") | undefined;
        "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
        "aria-orientation"?: "horizontal" | "vertical" | undefined;
        "aria-owns"?: string | undefined;
        "aria-placeholder"?: string | undefined;
        "aria-posinset"?: number | undefined;
        "aria-pressed"?: boolean | "false" | "mixed" | "true" | undefined;
        "aria-readonly"?: (boolean | "false" | "true") | undefined;
        "aria-relevant"?: "additions" | "additions removals" | "additions text" | "all" | "removals" | "removals additions" | "removals text" | "text" | "text additions" | "text removals" | undefined;
        "aria-required"?: (boolean | "false" | "true") | undefined;
        "aria-roledescription"?: string | undefined;
        "aria-rowcount"?: number | undefined;
        "aria-rowindex"?: number | undefined;
        "aria-rowindextext"?: string | undefined;
        "aria-rowspan"?: number | undefined;
        "aria-selected"?: (boolean | "false" | "true") | undefined;
        "aria-setsize"?: number | undefined;
        "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
        "aria-valuemax"?: number | undefined;
        "aria-valuemin"?: number | undefined;
        "aria-valuenow"?: number | undefined;
        "aria-valuetext"?: string | undefined;
        children?: import("react").ReactNode | undefined;
        dangerouslySetInnerHTML?: {
            __html: string | TrustedHTML;
        } | undefined;
        onCopy?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCopyCapture?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCut?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCutCapture?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPaste?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPasteCapture?: import("react").ClipboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionEnd?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionEndCapture?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionStart?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionStartCapture?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionUpdate?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCompositionUpdateCapture?: import("react").CompositionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onFocusCapture?: import("react").FocusEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onBlurCapture?: import("react").FocusEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onChangeCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onBeforeInput?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onBeforeInputCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onInput?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onInputCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onReset?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onResetCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSubmit?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSubmitCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onInvalid?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onInvalidCapture?: import("react").FormEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoad?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onError?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onErrorCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onKeyDownCapture?: import("react").KeyboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onKeyPress?: import("react").KeyboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onKeyPressCapture?: import("react").KeyboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onKeyUp?: import("react").KeyboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onKeyUpCapture?: import("react").KeyboardEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAbort?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAbortCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCanPlay?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCanPlayCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCanPlayThrough?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onCanPlayThroughCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDurationChange?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDurationChangeCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEmptied?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEmptiedCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEncrypted?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEncryptedCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEnded?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onEndedCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadedData?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadedDataCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadedMetadata?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadedMetadataCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadStart?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLoadStartCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPause?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPauseCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPlay?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPlayCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPlaying?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPlayingCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onProgress?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onProgressCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onRateChange?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onRateChangeCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onResize?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onResizeCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSeeked?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSeekedCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSeeking?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSeekingCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onStalled?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onStalledCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSuspend?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSuspendCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTimeUpdate?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTimeUpdateCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onVolumeChange?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onVolumeChangeCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onWaiting?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onWaitingCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAuxClick?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAuxClickCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onClick?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onClickCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onContextMenu?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onContextMenuCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDoubleClick?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDoubleClickCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDrag?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragEnd?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragEndCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragEnter?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragEnterCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragExit?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragExitCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragLeave?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragLeaveCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragOver?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragOverCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragStart?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDragStartCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDrop?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onDropCapture?: import("react").DragEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseDown?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseDownCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseEnter?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseLeave?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseMove?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseMoveCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseOut?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseOutCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseOver?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseOverCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseUp?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onMouseUpCapture?: import("react").MouseEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSelect?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onSelectCapture?: import("react").ReactEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchCancel?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchCancelCapture?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchEnd?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchEndCapture?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchMove?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchMoveCapture?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchStart?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTouchStartCapture?: import("react").TouchEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerDown?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerDownCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerMove?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerMoveCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerUp?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerUpCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerCancel?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerCancelCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerEnter?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerLeave?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerOver?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerOverCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerOut?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onPointerOutCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onGotPointerCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onGotPointerCaptureCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLostPointerCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onLostPointerCaptureCapture?: import("react").PointerEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onScroll?: import("react").UIEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onScrollCapture?: import("react").UIEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onWheel?: import("react").WheelEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onWheelCapture?: import("react").WheelEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationStart?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationStartCapture?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationEnd?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationEndCapture?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationIteration?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onAnimationIterationCapture?: import("react").AnimationEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTransitionEnd?: import("react").TransitionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
        onTransitionEndCapture?: import("react").TransitionEventHandler<HTMLInputElement | HTMLTextAreaElement> | undefined;
    };
    descriptionIdentifier: string;
};
